@@ -28,132 +28,155 @@
 package org.apache.http.impl.client;
 
 import java.io.IOException;
-import java.net.URI;
 import java.lang.reflect.UndeclaredThrowableException;
-
-import org.apache.http.annotation.ThreadSafe;
-import org.apache.http.annotation.GuardedBy;
+import java.net.URI;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.http.ConnectionReuseStrategy;
+import org.apache.http.HttpEntity;
 import org.apache.http.HttpException;
 import org.apache.http.HttpHost;
 import org.apache.http.HttpRequest;
 import org.apache.http.HttpRequestInterceptor;
 import org.apache.http.HttpResponse;
 import org.apache.http.HttpResponseInterceptor;
-import org.apache.http.HttpEntity;
+import org.apache.http.annotation.GuardedBy;
+import org.apache.http.annotation.ThreadSafe;
 import org.apache.http.auth.AuthSchemeRegistry;
 import org.apache.http.client.AuthenticationHandler;
 import org.apache.http.client.ClientProtocolException;
-import org.apache.http.client.RequestDirector;
-import org.apache.http.client.ResponseHandler;
 import org.apache.http.client.CookieStore;
 import org.apache.http.client.CredentialsProvider;
 import org.apache.http.client.HttpClient;
 import org.apache.http.client.HttpRequestRetryHandler;
 import org.apache.http.client.RedirectHandler;
+import org.apache.http.client.RedirectStrategy;
+import org.apache.http.client.RequestDirector;
+import org.apache.http.client.ResponseHandler;
 import org.apache.http.client.UserTokenHandler;
 import org.apache.http.client.methods.HttpUriRequest;
+import org.apache.http.client.params.AuthPolicy;
+import org.apache.http.client.params.ClientPNames;
+import org.apache.http.client.params.CookiePolicy;
+import org.apache.http.client.protocol.ClientContext;
+import org.apache.http.client.utils.URIUtils;
 import org.apache.http.conn.ClientConnectionManager;
+import org.apache.http.conn.ClientConnectionManagerFactory;
 import org.apache.http.conn.ConnectionKeepAliveStrategy;
 import org.apache.http.conn.routing.HttpRoutePlanner;
+import org.apache.http.conn.scheme.SchemeRegistry;
 import org.apache.http.cookie.CookieSpecRegistry;
+import org.apache.http.impl.DefaultConnectionReuseStrategy;
+import org.apache.http.impl.auth.BasicSchemeFactory;
+import org.apache.http.impl.auth.DigestSchemeFactory;
+import org.apache.http.impl.auth.NTLMSchemeFactory;
+import org.apache.http.impl.auth.NegotiateSchemeFactory;
+import org.apache.http.impl.conn.DefaultHttpRoutePlanner;
+import org.apache.http.impl.conn.SchemeRegistryFactory;
+import org.apache.http.impl.conn.SingleClientConnManager;
+import org.apache.http.impl.cookie.BestMatchSpecFactory;
+import org.apache.http.impl.cookie.BrowserCompatSpecFactory;
+import org.apache.http.impl.cookie.IgnoreSpecFactory;
+import org.apache.http.impl.cookie.NetscapeDraftSpecFactory;
+import org.apache.http.impl.cookie.RFC2109SpecFactory;
+import org.apache.http.impl.cookie.RFC2965SpecFactory;
 import org.apache.http.params.HttpParams;
+import org.apache.http.protocol.BasicHttpContext;
 import org.apache.http.protocol.BasicHttpProcessor;
 import org.apache.http.protocol.DefaultedHttpContext;
 import org.apache.http.protocol.HttpContext;
 import org.apache.http.protocol.HttpProcessor;
 import org.apache.http.protocol.HttpRequestExecutor;
+import org.apache.http.protocol.ImmutableHttpProcessor;
+import org.apache.http.util.EntityUtils;
 
 /**
- * Base class for {@link HttpClient} implementations. This class acts as 
- * a facade to a number of special purpose handler or strategy 
- * implementations responsible for handling of a particular aspect of 
- * the HTTP protocol such as redirect or authentication handling or 
- * making decision about connection persistence and keep alive duration. 
- * This enables the users to selectively replace default implementation 
- * of those aspects with custom, application specific ones. This class 
+ * Base class for {@link HttpClient} implementations. This class acts as
+ * a facade to a number of special purpose handler or strategy
+ * implementations responsible for handling of a particular aspect of
+ * the HTTP protocol such as redirect or authentication handling or
+ * making decision about connection persistence and keep alive duration.
+ * This enables the users to selectively replace default implementation
+ * of those aspects with custom, application specific ones. This class
  * also provides factory methods to instantiate those objects:
  * <ul>
- *   <li>{@link HttpRequestExecutor}</li> object used to transmit messages 
+ *   <li>{@link HttpRequestExecutor}</li> object used to transmit messages
  *    over HTTP connections. The {@link #createRequestExecutor()} must be
- *    implemented by concrete super classes to instantiate this object.  
- *   <li>{@link BasicHttpProcessor}</li> object to manage a list of protocol 
- *    interceptors and apply cross-cutting protocol logic to all incoming 
+ *    implemented by concrete super classes to instantiate this object.
+ *   <li>{@link BasicHttpProcessor}</li> object to manage a list of protocol
+ *    interceptors and apply cross-cutting protocol logic to all incoming
  *    and outgoing HTTP messages. The {@link #createHttpProcessor()} must be
  *    implemented by concrete super classes to instantiate this object.
  *   <li>{@link HttpRequestRetryHandler}</li> object used to decide whether
- *    or not a failed HTTP request is safe to retry automatically.  
+ *    or not a failed HTTP request is safe to retry automatically.
  *    The {@link #createHttpRequestRetryHandler()} must be
  *    implemented by concrete super classes to instantiate this object.
- *   <li>{@link ClientConnectionManager}</li> object used to manage 
+ *   <li>{@link ClientConnectionManager}</li> object used to manage
  *    persistent HTTP connections.
- *   <li>{@link ConnectionReuseStrategy}</li> object used to decide whether 
- *    or not a HTTP connection can be kept alive and re-used for subsequent 
+ *   <li>{@link ConnectionReuseStrategy}</li> object used to decide whether
+ *    or not a HTTP connection can be kept alive and re-used for subsequent
  *    HTTP requests. The {@link #createConnectionReuseStrategy()} must be
  *    implemented by concrete super classes to instantiate this object.
  *   <li>{@link ConnectionKeepAliveStrategy}</li> object used to decide how
  *    long a persistent HTTP connection can be kept alive.
  *    The {@link #createConnectionKeepAliveStrategy()} must be
  *    implemented by concrete super classes to instantiate this object.
- *   <li>{@link CookieSpecRegistry}</li> object used to maintain a list of 
- *    supported cookie specifications. 
- *    The {@link #createCookieSpecRegistry()} must be implemented by concrete 
+ *   <li>{@link CookieSpecRegistry}</li> object used to maintain a list of
+ *    supported cookie specifications.
+ *    The {@link #createCookieSpecRegistry()} must be implemented by concrete
  *    super classes to instantiate this object.
  *   <li>{@link CookieStore}</li> object used to maintain a collection of
- *    cookies. The {@link #createCookieStore()} must be implemented by 
+ *    cookies. The {@link #createCookieStore()} must be implemented by
  *    concrete super classes to instantiate this object.
- *   <li>{@link AuthSchemeRegistry}</li> object used to maintain a list of 
- *    supported authentication schemes. 
- *    The {@link #createAuthSchemeRegistry()} must be implemented by concrete 
+ *   <li>{@link AuthSchemeRegistry}</li> object used to maintain a list of
+ *    supported authentication schemes.
+ *    The {@link #createAuthSchemeRegistry()} must be implemented by concrete
  *    super classes to instantiate this object.
- *   <li>{@link CredentialsProvider}</li> object used to maintain 
- *    a collection user credentials. The {@link #createCredentialsProvider()} 
- *    must be implemented by concrete super classes to instantiate 
+ *   <li>{@link CredentialsProvider}</li> object used to maintain
+ *    a collection user credentials. The {@link #createCredentialsProvider()}
+ *    must be implemented by concrete super classes to instantiate
  *    this object.
  *   <li>{@link AuthenticationHandler}</li> object used to authenticate
- *    against the target host. 
- *    The {@link #createTargetAuthenticationHandler()} must be implemented 
+ *    against the target host.
+ *    The {@link #createTargetAuthenticationHandler()} must be implemented
  *    by concrete super classes to instantiate this object.
  *   <li>{@link AuthenticationHandler}</li> object used to authenticate
- *    against the proxy host. 
- *    The {@link #createProxyAuthenticationHandler()} must be implemented 
+ *    against the proxy host.
+ *    The {@link #createProxyAuthenticationHandler()} must be implemented
  *    by concrete super classes to instantiate this object.
  *   <li>{@link HttpRoutePlanner}</li> object used to calculate a route
  *    for establishing a connection to the target host. The route
- *    may involve multiple intermediate hops. 
- *    The {@link #createHttpRoutePlanner()} must be implemented 
+ *    may involve multiple intermediate hops.
+ *    The {@link #createHttpRoutePlanner()} must be implemented
  *    by concrete super classes to instantiate this object.
- *   <li>{@link RedirectHandler}</li> object used to determine if an HTTP 
- *    request should be redirected to a new location in response to an HTTP 
- *    response received from the target server. 
- *    The {@link #createRedirectHandler()} must be implemented 
- *    by concrete super classes to instantiate this object.
- *   <li>{@link UserTokenHandler}</li> object used to determine if the 
- *    execution context is user identity specific. 
- *    The {@link #createUserTokenHandler()} must be implemented by 
+ *   <li>{@link RedirectStrategy}</li> object used to determine if an HTTP
+ *    request should be redirected to a new location in response to an HTTP
+ *    response received from the target server.
+ *   <li>{@link UserTokenHandler}</li> object used to determine if the
+ *    execution context is user identity specific.
+ *    The {@link #createUserTokenHandler()} must be implemented by
  *    concrete super classes to instantiate this object.
- * </ul> 
+ * </ul>
  * <p>
- *   This class also maintains a list of protocol interceptors intended 
- *   for processing outgoing requests and incoming responses and provides 
- *   methods for managing those interceptors. New protocol interceptors can be 
- *   introduced to the protocol processor chain or removed from it if needed. 
- *   Internally protocol interceptors are stored in a simple 
- *   {@link java.util.ArrayList}. They are executed in the same natural order 
+ *   This class also maintains a list of protocol interceptors intended
+ *   for processing outgoing requests and incoming responses and provides
+ *   methods for managing those interceptors. New protocol interceptors can be
+ *   introduced to the protocol processor chain or removed from it if needed.
+ *   Internally protocol interceptors are stored in a simple
+ *   {@link java.util.ArrayList}. They are executed in the same natural order
  *   as they are added to the list.
  * <p>
- *   AbstractHttpClient is thread safe. It is recommended that the same 
- *   instance of this class is reused for multiple request executions. 
- *   When an instance of DefaultHttpClient is no longer needed and is about 
- *   to go out of scope the connection manager associated with it must be 
+ *   AbstractHttpClient is thread safe. It is recommended that the same
+ *   instance of this class is reused for multiple request executions.
+ *   When an instance of DefaultHttpClient is no longer needed and is about
+ *   to go out of scope the connection manager associated with it must be
  *   shut down by calling {@link ClientConnectionManager#shutdown()}!
  *
  * @since 4.0
  */
 @ThreadSafe
+@SuppressWarnings("deprecation")
 public abstract class AbstractHttpClient implements HttpClient {
 
     private final Log log = LogFactory.getLog(getClass());
@@ -173,7 +196,7 @@ public abstract class AbstractHttpClient implements HttpClient {
     /** The connection re-use strategy. */
     @GuardedBy("this")
     private ConnectionReuseStrategy reuseStrategy;
-    
+
     /** The connection keep-alive strategy. */
     @GuardedBy("this")
     private ConnectionKeepAliveStrategy keepAliveStrategy;
@@ -185,10 +208,13 @@ public abstract class AbstractHttpClient implements HttpClient {
     /** The authentication scheme registry. */
     @GuardedBy("this")
     private AuthSchemeRegistry supportedAuthSchemes;
-    
-    /** The HTTP processor. */
+
+    /** The HTTP protocol processor and its immutable copy. */
     @GuardedBy("this")
-    private BasicHttpProcessor httpProcessor;
+    private BasicHttpProcessor mutableProcessor;
+
+    @GuardedBy("this")
+    private ImmutableHttpProcessor protocolProcessor;
 
     /** The request retry handler. */
     @GuardedBy("this")
@@ -196,7 +222,7 @@ public abstract class AbstractHttpClient implements HttpClient {
 
     /** The redirect handler. */
     @GuardedBy("this")
-    private RedirectHandler redirectHandler;
+    private RedirectStrategy redirectStrategy;
 
     /** The target authentication handler. */
     @GuardedBy("this")
@@ -213,7 +239,7 @@ public abstract class AbstractHttpClient implements HttpClient {
     /** The credentials provider. */
     @GuardedBy("this")
     private CredentialsProvider credsProvider;
-    
+
     /** The route planner. */
     @GuardedBy("this")
     private HttpRoutePlanner routePlanner;
@@ -236,57 +262,164 @@ public abstract class AbstractHttpClient implements HttpClient {
         connManager          = conman;
     } // constructor
 
+
     protected abstract HttpParams createHttpParams();
 
-    
-    protected abstract HttpContext createHttpContext();
 
-    
-    protected abstract HttpRequestExecutor createRequestExecutor();
-
-
-    protected abstract ClientConnectionManager createClientConnectionManager();
-
-
-    protected abstract AuthSchemeRegistry createAuthSchemeRegistry();
-
-    
-    protected abstract CookieSpecRegistry createCookieSpecRegistry();
-
-    
-    protected abstract ConnectionReuseStrategy createConnectionReuseStrategy();
-
-    
-    protected abstract ConnectionKeepAliveStrategy createConnectionKeepAliveStrategy();
-
-    
     protected abstract BasicHttpProcessor createHttpProcessor();
 
-    
-    protected abstract HttpRequestRetryHandler createHttpRequestRetryHandler();
 
-    
-    protected abstract RedirectHandler createRedirectHandler();
+    protected HttpContext createHttpContext() {
+        HttpContext context = new BasicHttpContext();
+        context.setAttribute(
+                ClientContext.SCHEME_REGISTRY,
+                getConnectionManager().getSchemeRegistry());
+        context.setAttribute(
+                ClientContext.AUTHSCHEME_REGISTRY,
+                getAuthSchemes());
+        context.setAttribute(
+                ClientContext.COOKIESPEC_REGISTRY,
+                getCookieSpecs());
+        context.setAttribute(
+                ClientContext.COOKIE_STORE,
+                getCookieStore());
+        context.setAttribute(
+                ClientContext.CREDS_PROVIDER,
+                getCredentialsProvider());
+        return context;
+    }
 
-    
-    protected abstract AuthenticationHandler createTargetAuthenticationHandler();
 
-    
-    protected abstract AuthenticationHandler createProxyAuthenticationHandler();
+    protected ClientConnectionManager createClientConnectionManager() {
+        SchemeRegistry registry = SchemeRegistryFactory.createDefault();
 
-    
-    protected abstract CookieStore createCookieStore();
-    
-    
-    protected abstract CredentialsProvider createCredentialsProvider();
-    
-    
-    protected abstract HttpRoutePlanner createHttpRoutePlanner();
+        ClientConnectionManager connManager = null;
+        HttpParams params = getParams();
+
+        ClientConnectionManagerFactory factory = null;
+
+        String className = (String) params.getParameter(
+                ClientPNames.CONNECTION_MANAGER_FACTORY_CLASS_NAME);
+        if (className != null) {
+            try {
+                Class<?> clazz = Class.forName(className);
+                factory = (ClientConnectionManagerFactory) clazz.newInstance();
+            } catch (ClassNotFoundException ex) {
+                throw new IllegalStateException("Invalid class name: " + className);
+            } catch (IllegalAccessException ex) {
+                throw new IllegalAccessError(ex.getMessage());
+            } catch (InstantiationException ex) {
+                throw new InstantiationError(ex.getMessage());
+            }
+        }
+        if (factory != null) {
+            connManager = factory.newInstance(params, registry);
+        } else {
+            connManager = new SingleClientConnManager(registry);
+        }
+
+        return connManager;
+    }
+
+
+    protected AuthSchemeRegistry createAuthSchemeRegistry() {
+        AuthSchemeRegistry registry = new AuthSchemeRegistry();
+        registry.register(
+                AuthPolicy.BASIC,
+                new BasicSchemeFactory());
+        registry.register(
+                AuthPolicy.DIGEST,
+                new DigestSchemeFactory());
+        registry.register(
+                AuthPolicy.NTLM,
+                new NTLMSchemeFactory());
+        registry.register(
+                AuthPolicy.SPNEGO,
+                new NegotiateSchemeFactory());
+        return registry;
+    }
+
+
+    protected CookieSpecRegistry createCookieSpecRegistry() {
+        CookieSpecRegistry registry = new CookieSpecRegistry();
+        registry.register(
+                CookiePolicy.BEST_MATCH,
+                new BestMatchSpecFactory());
+        registry.register(
+                CookiePolicy.BROWSER_COMPATIBILITY,
+                new BrowserCompatSpecFactory());
+        registry.register(
+                CookiePolicy.NETSCAPE,
+                new NetscapeDraftSpecFactory());
+        registry.register(
+                CookiePolicy.RFC_2109,
+                new RFC2109SpecFactory());
+        registry.register(
+                CookiePolicy.RFC_2965,
+                new RFC2965SpecFactory());
+        registry.register(
+                CookiePolicy.IGNORE_COOKIES,
+                new IgnoreSpecFactory());
+        return registry;
+    }
+
+
+    protected HttpRequestExecutor createRequestExecutor() {
+        return new HttpRequestExecutor();
+    }
+
+
+    protected ConnectionReuseStrategy createConnectionReuseStrategy() {
+        return new DefaultConnectionReuseStrategy();
+    }
+
+
+    protected ConnectionKeepAliveStrategy createConnectionKeepAliveStrategy() {
+        return new DefaultConnectionKeepAliveStrategy();
+    }
+
+
+    protected HttpRequestRetryHandler createHttpRequestRetryHandler() {
+        return new DefaultHttpRequestRetryHandler();
+    }
+
+
+    @Deprecated
+    protected RedirectHandler createRedirectHandler() {
+        return new DefaultRedirectHandler();
+    }
+
+
+    protected AuthenticationHandler createTargetAuthenticationHandler() {
+        return new DefaultTargetAuthenticationHandler();
+    }
+
+
+    protected AuthenticationHandler createProxyAuthenticationHandler() {
+        return new DefaultProxyAuthenticationHandler();
+    }
+
+
+    protected CookieStore createCookieStore() {
+        return new BasicCookieStore();
+    }
+
+
+    protected CredentialsProvider createCredentialsProvider() {
+        return new BasicCredentialsProvider();
+    }
+
+
+    protected HttpRoutePlanner createHttpRoutePlanner() {
+        return new DefaultHttpRoutePlanner(getConnectionManager().getSchemeRegistry());
+    }
+
+
+    protected UserTokenHandler createUserTokenHandler() {
+        return new DefaultUserTokenHandler();
+    }
 
-    
-    protected abstract UserTokenHandler createUserTokenHandler();
 
-    
     // non-javadoc, see interface HttpClient
     public synchronized final HttpParams getParams() {
         if (defaultParams == null) {
@@ -348,7 +481,7 @@ public abstract class AbstractHttpClient implements HttpClient {
         supportedCookieSpecs = cookieSpecRegistry;
     }
 
-    
+
     public synchronized final ConnectionReuseStrategy getConnectionReuseStrategy() {
         if (reuseStrategy == null) {
             reuseStrategy = createConnectionReuseStrategy();
@@ -361,7 +494,7 @@ public abstract class AbstractHttpClient implements HttpClient {
         this.reuseStrategy = reuseStrategy;
     }
 
-    
+
     public synchronized final ConnectionKeepAliveStrategy getConnectionKeepAliveStrategy() {
         if (keepAliveStrategy == null) {
             keepAliveStrategy = createConnectionKeepAliveStrategy();
@@ -369,7 +502,7 @@ public abstract class AbstractHttpClient implements HttpClient {
         return keepAliveStrategy;
     }
 
-    
+
     public synchronized void setKeepAliveStrategy(final ConnectionKeepAliveStrategy keepAliveStrategy) {
         this.keepAliveStrategy = keepAliveStrategy;
     }
@@ -388,16 +521,32 @@ public abstract class AbstractHttpClient implements HttpClient {
     }
 
 
+    @Deprecated
     public synchronized final RedirectHandler getRedirectHandler() {
-        if (redirectHandler == null) {
-            redirectHandler = createRedirectHandler();
-        }
-        return redirectHandler;
+        return createRedirectHandler();
     }
 
 
+    @Deprecated
     public synchronized void setRedirectHandler(final RedirectHandler redirectHandler) {
-        this.redirectHandler = redirectHandler;
+        this.redirectStrategy = new DefaultRedirectStrategyAdaptor(redirectHandler);
+    }
+
+    /**
+     * @since 4.1
+     */
+    public synchronized final RedirectStrategy getRedirectStrategy() {
+        if (redirectStrategy == null) {
+            redirectStrategy = new DefaultRedirectStrategy();
+        }
+        return redirectStrategy;
+    }
+
+    /**
+     * @since 4.1
+     */
+    public synchronized void setRedirectStrategy(final RedirectStrategy redirectStrategy) {
+        this.redirectStrategy = redirectStrategy;
     }
 
 
@@ -466,8 +615,8 @@ public abstract class AbstractHttpClient implements HttpClient {
     public synchronized void setRoutePlanner(final HttpRoutePlanner routePlanner) {
         this.routePlanner = routePlanner;
     }
-    
-    
+
+
     public synchronized final UserTokenHandler getUserTokenHandler() {
         if (this.userTokenHandler == null) {
             this.userTokenHandler = createUserTokenHandler();
@@ -479,28 +628,34 @@ public abstract class AbstractHttpClient implements HttpClient {
     public synchronized void setUserTokenHandler(final UserTokenHandler userTokenHandler) {
         this.userTokenHandler = userTokenHandler;
     }
-    
-    
+
+
     protected synchronized final BasicHttpProcessor getHttpProcessor() {
-        if (httpProcessor == null) {
-            httpProcessor = createHttpProcessor();
+        if (mutableProcessor == null) {
+            mutableProcessor = createHttpProcessor();
         }
-        return httpProcessor;
+        return mutableProcessor;
     }
 
 
-    public synchronized void addResponseInterceptor(final HttpResponseInterceptor itcp) {
-        getHttpProcessor().addInterceptor(itcp);
-    }
-
-
-    public synchronized void addResponseInterceptor(final HttpResponseInterceptor itcp, int index) {
-        getHttpProcessor().addInterceptor(itcp, index);
-    }
-
-
-    public synchronized HttpResponseInterceptor getResponseInterceptor(int index) {
-        return getHttpProcessor().getResponseInterceptor(index);
+    private synchronized final HttpProcessor getProtocolProcessor() {
+        if (protocolProcessor == null) {
+            // Get mutable HTTP processor
+            BasicHttpProcessor proc = getHttpProcessor();
+            // and create an immutable copy of it
+            int reqc = proc.getRequestInterceptorCount();
+            HttpRequestInterceptor[] reqinterceptors = new HttpRequestInterceptor[reqc];
+            for (int i = 0; i < reqc; i++) {
+                reqinterceptors[i] = proc.getRequestInterceptor(i);
+            }
+            int resc = proc.getResponseInterceptorCount();
+            HttpResponseInterceptor[] resinterceptors = new HttpResponseInterceptor[resc];
+            for (int i = 0; i < resc; i++) {
+                resinterceptors[i] = proc.getResponseInterceptor(i);
+            }
+            protocolProcessor = new ImmutableHttpProcessor(reqinterceptors, resinterceptors);
+        }
+        return protocolProcessor;
     }
 
 
@@ -509,23 +664,8 @@ public abstract class AbstractHttpClient implements HttpClient {
     }
 
 
-    public synchronized void clearResponseInterceptors() {
-        getHttpProcessor().clearResponseInterceptors();
-    }
-
-
-    public synchronized void removeResponseInterceptorByClass(Class<? extends HttpResponseInterceptor> clazz) {
-        getHttpProcessor().removeResponseInterceptorByClass(clazz);
-    }
-
-    
-    public synchronized void addRequestInterceptor(final HttpRequestInterceptor itcp) {
-        getHttpProcessor().addInterceptor(itcp);
-    }
-
-
-    public synchronized void addRequestInterceptor(final HttpRequestInterceptor itcp, int index) {
-        getHttpProcessor().addInterceptor(itcp, index);
+    public synchronized HttpResponseInterceptor getResponseInterceptor(int index) {
+        return getHttpProcessor().getResponseInterceptor(index);
     }
 
 
@@ -539,13 +679,51 @@ public abstract class AbstractHttpClient implements HttpClient {
     }
 
 
+    public synchronized void addResponseInterceptor(final HttpResponseInterceptor itcp) {
+        getHttpProcessor().addInterceptor(itcp);
+        protocolProcessor = null;
+    }
+
+
+    public synchronized void addResponseInterceptor(final HttpResponseInterceptor itcp, int index) {
+        getHttpProcessor().addInterceptor(itcp, index);
+        protocolProcessor = null;
+    }
+
+
+    public synchronized void clearResponseInterceptors() {
+        getHttpProcessor().clearResponseInterceptors();
+        protocolProcessor = null;
+    }
+
+
+    public synchronized void removeResponseInterceptorByClass(Class<? extends HttpResponseInterceptor> clazz) {
+        getHttpProcessor().removeResponseInterceptorByClass(clazz);
+        protocolProcessor = null;
+    }
+
+
+    public synchronized void addRequestInterceptor(final HttpRequestInterceptor itcp) {
+        getHttpProcessor().addInterceptor(itcp);
+        protocolProcessor = null;
+    }
+
+
+    public synchronized void addRequestInterceptor(final HttpRequestInterceptor itcp, int index) {
+        getHttpProcessor().addInterceptor(itcp, index);
+        protocolProcessor = null;
+    }
+
+
     public synchronized void clearRequestInterceptors() {
         getHttpProcessor().clearRequestInterceptors();
+        protocolProcessor = null;
     }
 
 
     public synchronized void removeRequestInterceptorByClass(Class<? extends HttpRequestInterceptor> clazz) {
         getHttpProcessor().removeRequestInterceptorByClass(clazz);
+        protocolProcessor = null;
     }
 
     public final HttpResponse execute(HttpUriRequest request)
@@ -576,17 +754,18 @@ public abstract class AbstractHttpClient implements HttpClient {
         return execute(determineTarget(request), request, context);
     }
 
-    private HttpHost determineTarget(HttpUriRequest request) {
+    private static HttpHost determineTarget(HttpUriRequest request) throws ClientProtocolException {
         // A null target may be acceptable if there is a default target.
         // Otherwise, the null target is detected in the director.
         HttpHost target = null;
 
         URI requestURI = request.getURI();
         if (requestURI.isAbsolute()) {
-            target = new HttpHost(
-                    requestURI.getHost(),
-                    requestURI.getPort(),
-                    requestURI.getScheme());
+            target = URIUtils.extractHost(requestURI);
+            if (target == null) {
+                throw new ClientProtocolException(
+                        "URI does not specify a valid host name: " + requestURI);
+            }
         }
         return target;
     }
@@ -610,8 +789,8 @@ public abstract class AbstractHttpClient implements HttpClient {
 
         HttpContext execContext = null;
         RequestDirector director = null;
-        
-        // Initialize the request execution context making copies of 
+
+        // Initialize the request execution context making copies of
         // all shared objects that are potentially threading unsafe.
         synchronized (this) {
 
@@ -628,9 +807,9 @@ public abstract class AbstractHttpClient implements HttpClient {
                     getConnectionReuseStrategy(),
                     getConnectionKeepAliveStrategy(),
                     getRoutePlanner(),
-                    getHttpProcessor().copy(),
+                    getProtocolProcessor(),
                     getHttpRequestRetryHandler(),
-                    getRedirectHandler(),
+                    getRedirectStrategy(),
                     getTargetAuthenticationHandler(),
                     getProxyAuthenticationHandler(),
                     getUserTokenHandler(),
@@ -644,6 +823,7 @@ public abstract class AbstractHttpClient implements HttpClient {
         }
     }
 
+    @Deprecated
     protected RequestDirector createClientRequestDirector(
             final HttpRequestExecutor requestExec,
             final ClientConnectionManager conman,
@@ -652,13 +832,12 @@ public abstract class AbstractHttpClient implements HttpClient {
             final HttpRoutePlanner rouplan,
             final HttpProcessor httpProcessor,
             final HttpRequestRetryHandler retryHandler,
-            final RedirectHandler redirectHandler,
+            final org.apache.http.client.RedirectHandler redirectHandler,
             final AuthenticationHandler targetAuthHandler,
             final AuthenticationHandler proxyAuthHandler,
             final UserTokenHandler stateHandler,
             final HttpParams params) {
         return new DefaultRequestDirector(
-                log,
                 requestExec,
                 conman,
                 reustrat,
@@ -673,6 +852,37 @@ public abstract class AbstractHttpClient implements HttpClient {
                 params);
     }
 
+    /**
+     * @since 4.1
+     */
+    protected RequestDirector createClientRequestDirector(
+            final HttpRequestExecutor requestExec,
+            final ClientConnectionManager conman,
+            final ConnectionReuseStrategy reustrat,
+            final ConnectionKeepAliveStrategy kastrat,
+            final HttpRoutePlanner rouplan,
+            final HttpProcessor httpProcessor,
+            final HttpRequestRetryHandler retryHandler,
+            final RedirectStrategy redirectStrategy,
+            final AuthenticationHandler targetAuthHandler,
+            final AuthenticationHandler proxyAuthHandler,
+            final UserTokenHandler stateHandler,
+            final HttpParams params) {
+        return new DefaultRequestDirector(
+                log,
+                requestExec,
+                conman,
+                reustrat,
+                kastrat,
+                rouplan,
+                httpProcessor,
+                retryHandler,
+                redirectStrategy,
+                targetAuthHandler,
+                proxyAuthHandler,
+                stateHandler,
+                params);
+    }
     /**
      * Obtains parameters for executing a request.
      * The default implementation in this class creates a new
@@ -694,15 +904,15 @@ public abstract class AbstractHttpClient implements HttpClient {
     }
 
     public <T> T execute(
-            final HttpUriRequest request, 
-            final ResponseHandler<? extends T> responseHandler) 
+            final HttpUriRequest request,
+            final ResponseHandler<? extends T> responseHandler)
                 throws IOException, ClientProtocolException {
         return execute(request, responseHandler, null);
     }
 
     public <T> T execute(
             final HttpUriRequest request,
-            final ResponseHandler<? extends T> responseHandler, 
+            final ResponseHandler<? extends T> responseHandler,
             final HttpContext context)
                 throws IOException, ClientProtocolException {
         HttpHost target = determineTarget(request);
@@ -710,18 +920,18 @@ public abstract class AbstractHttpClient implements HttpClient {
     }
 
     public <T> T execute(
-            final HttpHost target, 
+            final HttpHost target,
             final HttpRequest request,
-            final ResponseHandler<? extends T> responseHandler) 
+            final ResponseHandler<? extends T> responseHandler)
                 throws IOException, ClientProtocolException {
         return execute(target, request, responseHandler, null);
     }
 
     public <T> T execute(
-            final HttpHost target, 
+            final HttpHost target,
             final HttpRequest request,
-            final ResponseHandler<? extends T> responseHandler, 
-            final HttpContext context) 
+            final ResponseHandler<? extends T> responseHandler,
+            final HttpContext context)
                 throws IOException, ClientProtocolException {
         if (responseHandler == null) {
             throw new IllegalArgumentException
@@ -735,14 +945,12 @@ public abstract class AbstractHttpClient implements HttpClient {
             result = responseHandler.handleResponse(response);
         } catch (Throwable t) {
             HttpEntity entity = response.getEntity();
-            if (entity != null) {
-                try {
-                    entity.consumeContent();
-                } catch (Throwable t2) {
-                    // Log this exception. The original exception is more
-                    // important and will be thrown to the caller.
-                    this.log.warn("Error consuming content after an exception.", t2);
-                }
+            try {
+                EntityUtils.consume(entity);
+            } catch (Exception t2) {
+                // Log this exception. The original exception is more
+                // important and will be thrown to the caller.
+                this.log.warn("Error consuming content after an exception.", t2);
             }
 
             if (t instanceof Error) {
@@ -756,18 +964,14 @@ public abstract class AbstractHttpClient implements HttpClient {
             if (t instanceof IOException) {
                 throw (IOException) t;
             }
-            
+
             throw new UndeclaredThrowableException(t);
         }
 
         // Handling the response was successful. Ensure that the content has
         // been fully consumed.
         HttpEntity entity = response.getEntity();
-        if (entity != null) {
-            // Let this exception go to the caller.
-            entity.consumeContent();
-        }
-
+        EntityUtils.consume(entity);
         return result;
     }
 
