@@ -31,6 +31,8 @@ import java.util.concurrent.TimeUnit;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import org.apache.http.annotation.ThreadSafe;
+import org.apache.http.conn.params.ConnPerRouteBean;
 import org.apache.http.conn.routing.HttpRoute;
 import org.apache.http.conn.scheme.SchemeRegistry;
 import org.apache.http.conn.ClientConnectionManager;
@@ -41,67 +43,104 @@ import org.apache.http.conn.ManagedClientConnection;
 import org.apache.http.conn.OperatedClientConnection;
 import org.apache.http.params.HttpParams;
 import org.apache.http.impl.conn.DefaultClientConnectionOperator;
+import org.apache.http.impl.conn.SchemeRegistryFactory;
 
 /**
- * Manages a pool of {@link OperatedClientConnection client connections} and 
- * is able to service connection requests from multiple execution threads. 
- * Connections are pooled on a per route basis. A request for a route which 
- * already the manager has persistent connections for available in the pool 
- * will be services by leasing a connection from the pool rather than 
+ * Manages a pool of {@link OperatedClientConnection client connections} and
+ * is able to service connection requests from multiple execution threads.
+ * Connections are pooled on a per route basis. A request for a route which
+ * already the manager has persistent connections for available in the pool
+ * will be services by leasing a connection from the pool rather than
  * creating a brand new connection.
  * <p>
- * ThreadSafeClientConnManager maintains a maximum limit of connection on 
+ * ThreadSafeClientConnManager maintains a maximum limit of connection on
  * a per route basis and in total. Per default this implementation will
- * create no more than than 2 concurrent connections per given route 
+ * create no more than than 2 concurrent connections per given route
  * and no more 20 connections in total. For many real-world applications
  * these limits may prove too constraining, especially if they use HTTP
  * as a transport protocol for their services. Connection limits, however,
  * can be adjusted using HTTP parameters.
- * <p>
- * The following parameters can be used to customize the behavior of this 
- * class: 
- * <ul>
- *  <li>{@link org.apache.http.conn.params.ConnManagerPNames#MAX_TOTAL_CONNECTIONS}</li>
- *  <li>{@link org.apache.http.conn.params.ConnManagerPNames#MAX_CONNECTIONS_PER_ROUTE}</li>
- * </ul>
- *
- * @see org.apache.http.conn.params.ConnPerRoute 
- * @see org.apache.http.conn.params.ConnPerRouteBean
  *
  * @since 4.0
  */
+@ThreadSafe
 public class ThreadSafeClientConnManager implements ClientConnectionManager {
 
-    private final Log log = LogFactory.getLog(getClass());
+    private final Log log;
 
     /** The schemes supported by this connection manager. */
     protected final SchemeRegistry schemeRegistry; // @ThreadSafe
-    
-    /** The pool of connections being managed. */
+
+    @Deprecated
     protected final AbstractConnPool connectionPool;
 
+    /** The pool of connections being managed. */
+    protected final ConnPoolByRoute pool;
+
     /** The operator for opening and updating connections. */
     protected final ClientConnectionOperator connOperator; // DefaultClientConnectionOperator is @ThreadSafe
-    
+
+    protected final ConnPerRouteBean connPerRoute;
+
+    /**
+     * Creates a new thread safe connection manager.
+     *
+     * @param schreg    the scheme registry.
+     */
+    public ThreadSafeClientConnManager(final SchemeRegistry schreg) {
+        this(schreg, -1, TimeUnit.MILLISECONDS);
+    }
+
+    /**
+     * @since 4.1
+     */
+    public ThreadSafeClientConnManager() {
+        this(SchemeRegistryFactory.createDefault());
+    }
+
+    /**
+     * Creates a new thread safe connection manager.
+     *
+     * @param schreg    the scheme registry.
+     * @param connTTL   max connection lifetime, <=0 implies "infinity"
+     * @param connTTLTimeUnit   TimeUnit of connTTL
+     *
+     * @since 4.1
+     */
+    public ThreadSafeClientConnManager(final SchemeRegistry schreg,
+            long connTTL, TimeUnit connTTLTimeUnit) {
+        super();
+        if (schreg == null) {
+            throw new IllegalArgumentException("Scheme registry may not be null");
+        }
+        this.log = LogFactory.getLog(getClass());
+        this.schemeRegistry = schreg;
+        this.connPerRoute = new ConnPerRouteBean();
+        this.connOperator = createConnectionOperator(schreg);
+        this.pool = createConnectionPool(connTTL, connTTLTimeUnit) ;
+        this.connectionPool = this.pool;
+    }
+
     /**
      * Creates a new thread safe connection manager.
      *
      * @param params    the parameters for this manager.
      * @param schreg    the scheme registry.
+     *
+     * @deprecated use {@link ThreadSafeClientConnManager#ThreadSafeClientConnManager(SchemeRegistry)}
      */
+    @Deprecated
     public ThreadSafeClientConnManager(HttpParams params,
                                        SchemeRegistry schreg) {
-
-        if (params == null) {
-            throw new IllegalArgumentException("HTTP parameters may not be null");
-        }
         if (schreg == null) {
             throw new IllegalArgumentException("Scheme registry may not be null");
         }
+        this.log = LogFactory.getLog(getClass());
         this.schemeRegistry = schreg;
-        this.connOperator   = createConnectionOperator(schreg);
-        this.connectionPool = createConnectionPool(params);
-
+        this.connPerRoute = new ConnPerRouteBean();
+        this.connOperator = createConnectionOperator(schreg);
+        this.pool = (ConnPoolByRoute) createConnectionPool(params) ;
+        this.connectionPool = this.pool;
     }
 
     @Override
@@ -117,11 +156,25 @@ public class ThreadSafeClientConnManager implements ClientConnectionManager {
      * Hook for creating the connection pool.
      *
      * @return  the connection pool to use
+     *
+     * @deprecated use #createConnectionPool(long, TimeUnit))
      */
+    @Deprecated
     protected AbstractConnPool createConnectionPool(final HttpParams params) {
         return new ConnPoolByRoute(connOperator, params);
     }
 
+    /**
+     * Hook for creating the connection pool.
+     *
+     * @return  the connection pool to use
+     *
+     * @since 4.1
+     */
+    protected ConnPoolByRoute createConnectionPool(long connTTL, TimeUnit connTTLTimeUnit) {
+        return new ConnPoolByRoute(connOperator, connPerRoute, 20, connTTL, connTTLTimeUnit);
+    }
+
     /**
      * Hook for creating the connection operator.
      * It is called by the constructor.
@@ -145,18 +198,18 @@ public class ThreadSafeClientConnManager implements ClientConnectionManager {
     }
 
     public ClientConnectionRequest requestConnection(
-            final HttpRoute route, 
+            final HttpRoute route,
             final Object state) {
-        
-        final PoolEntryRequest poolRequest = connectionPool.requestPoolEntry(
+
+        final PoolEntryRequest poolRequest = pool.requestPoolEntry(
                 route, state);
-        
+
         return new ClientConnectionRequest() {
-            
+
             public void abortRequest() {
                 poolRequest.abortRequest();
             }
-            
+
             public ManagedClientConnection getConnection(
                     long timeout, TimeUnit tunit) throws InterruptedException,
                     ConnectionPoolTimeoutException {
@@ -171,9 +224,9 @@ public class ThreadSafeClientConnManager implements ClientConnectionManager {
                 BasicPoolEntry entry = poolRequest.getPoolEntry(timeout, tunit);
                 return new BasicPooledConnAdapter(ThreadSafeClientConnManager.this, entry);
             }
-            
+
         };
-        
+
     }
 
     public void releaseConnection(ManagedClientConnection conn, long validDuration, TimeUnit timeUnit) {
@@ -220,14 +273,14 @@ public class ThreadSafeClientConnManager implements ClientConnectionManager {
                     }
                 }
                 hca.detach();
-                connectionPool.freeEntry(entry, reusable, validDuration, timeUnit);
+                pool.freeEntry(entry, reusable, validDuration, timeUnit);
             }
         }
     }
 
     public void shutdown() {
         log.debug("Shutting down");
-        connectionPool.shutdown();
+        pool.shutdown();
     }
 
     /**
@@ -235,55 +288,79 @@ public class ThreadSafeClientConnManager implements ClientConnectionManager {
      * This is the total number of connections that have been created and
      * are still in use by this connection manager for the route.
      * This value will not exceed the maximum number of connections per host.
-     * 
+     *
      * @param route     the route in question
      *
      * @return  the total number of pooled connections for that route
      */
-    public int getConnectionsInPool(HttpRoute route) {
-        return ((ConnPoolByRoute)connectionPool).getConnectionsInPool(
-                route);
+    public int getConnectionsInPool(final HttpRoute route) {
+        return pool.getConnectionsInPool(route);
     }
 
     /**
-     * Gets the total number of pooled connections.  This is the total number of 
-     * connections that have been created and are still in use by this connection 
+     * Gets the total number of pooled connections.  This is the total number of
+     * connections that have been created and are still in use by this connection
      * manager.  This value will not exceed the maximum number of connections
      * in total.
-     * 
+     *
      * @return the total number of pooled connections
      */
     public int getConnectionsInPool() {
-        connectionPool.poolLock.lock();
-        try {
-            return connectionPool.numConnections;
-        } finally {
-            connectionPool.poolLock.unlock();
-        }
+        return pool.getConnectionsInPool();
     }
 
     public void closeIdleConnections(long idleTimeout, TimeUnit tunit) {
         if (log.isDebugEnabled()) {
-            log.debug("Closing connections idle for " + idleTimeout + " " + tunit);
-        }
-        connectionPool.poolLock.lock();
-        try {
-            connectionPool.closeIdleConnections(idleTimeout, tunit);
-            connectionPool.deleteClosedConnections();
-        } finally {
-            connectionPool.poolLock.unlock();
+            log.debug("Closing connections idle longer than " + idleTimeout + " " + tunit);
         }
+        pool.closeIdleConnections(idleTimeout, tunit);
     }
-    
+
     public void closeExpiredConnections() {
         log.debug("Closing expired connections");
-        connectionPool.poolLock.lock();
-        try {
-            connectionPool.closeExpiredConnections();
-            connectionPool.deleteClosedConnections();
-        } finally {
-            connectionPool.poolLock.unlock();
-        }
+        pool.closeExpiredConnections();
+    }
+
+    /**
+     * since 4.1
+     */
+    public int getMaxTotal() {
+        return pool.getMaxTotalConnections();
+    }
+
+    /**
+     * since 4.1
+     */
+    public void setMaxTotal(int max) {
+        pool.setMaxTotalConnections(max);
+    }
+
+    /**
+     * @since 4.1
+     */
+    public int getDefaultMaxPerRoute() {
+        return connPerRoute.getDefaultMaxPerRoute();
+    }
+
+    /**
+     * @since 4.1
+     */
+    public void setDefaultMaxPerRoute(int max) {
+        connPerRoute.setDefaultMaxPerRoute(max);
+    }
+
+    /**
+     * @since 4.1
+     */
+    public int getMaxForRoute(final HttpRoute route) {
+        return connPerRoute.getMaxForRoute(route);
+    }
+
+    /**
+     * @since 4.1
+     */
+    public void setMaxForRoute(final HttpRoute route, int max) {
+        connPerRoute.setMaxForRoute(route, max);
     }
 
 }
