@@ -27,11 +27,11 @@
 package org.apache.http.client.protocol;
 
 import java.io.IOException;
+import java.net.InetSocketAddress;
 import java.util.ArrayList;
 import java.util.List;
 
 import org.apache.http.Header;
-import org.apache.http.HttpEntity;
 import org.apache.http.HttpException;
 import org.apache.http.HttpHost;
 import org.apache.http.HttpRequest;
@@ -59,42 +59,25 @@ import org.apache.http.protocol.ExecutionContext;
 import org.apache.http.protocol.HTTP;
 import org.apache.http.protocol.HttpContext;
 import org.apache.http.protocol.HttpRequestHandler;
-
-import junit.framework.Test;
-import junit.framework.TestSuite;
+import org.apache.http.util.EntityUtils;
+import org.junit.Assert;
+import org.junit.Before;
+import org.junit.Test;
 
 /**
  * Redirection test cases.
- *
  */
 public class TestRedirects extends BasicServerTestBase {
 
-    // ------------------------------------------------------------ Constructor
-    public TestRedirects(final String testName) {
-        super(testName);
-    }
-
-    // ------------------------------------------------------------------- Main
-    public static void main(String args[]) {
-        String[] testCaseName = { TestRedirects.class.getName() };
-        junit.textui.TestRunner.main(testCaseName);
-    }
-
-    // ------------------------------------------------------- TestCase Methods
-
-    public static Test suite() {
-        return new TestSuite(TestRedirects.class);
-    }
-
-    @Override
-    protected void setUp() throws Exception {
+    @Before
+    public void setUp() throws Exception {
         localServer = new LocalTestServer(null, null);
         localServer.registerDefaultHandlers();
         localServer.start();
     }
-    
-    private class BasicRedirectService implements HttpRequestHandler {
-        
+
+    private static class BasicRedirectService implements HttpRequestHandler {
+
         private int statuscode = HttpStatus.SC_MOVED_TEMPORARILY;
         private String host = null;
         private int port;
@@ -113,14 +96,14 @@ public class TestRedirects extends BasicServerTestBase {
         }
 
         public void handle(
-                final HttpRequest request, 
-                final HttpResponse response, 
+                final HttpRequest request,
+                final HttpResponse response,
                 final HttpContext context) throws HttpException, IOException {
             ProtocolVersion ver = request.getRequestLine().getProtocolVersion();
             String uri = request.getRequestLine().getUri();
             if (uri.equals("/oldlocation/")) {
                 response.setStatusLine(ver, this.statuscode);
-                response.addHeader(new BasicHeader("Location", 
+                response.addHeader(new BasicHeader("Location",
                         "http://" + this.host + ":" + this.port + "/newlocation/"));
                 response.addHeader(new BasicHeader("Connection", "close"));
             } else if (uri.equals("/newlocation/")) {
@@ -133,15 +116,15 @@ public class TestRedirects extends BasicServerTestBase {
         }
     }
 
-    private class CircularRedirectService implements HttpRequestHandler {
+    private static class CircularRedirectService implements HttpRequestHandler {
 
         public CircularRedirectService() {
             super();
         }
-        
+
         public void handle(
-                final HttpRequest request, 
-                final HttpResponse response, 
+                final HttpRequest request,
+                final HttpResponse response,
                 final HttpContext context) throws HttpException, IOException {
             ProtocolVersion ver = request.getRequestLine().getProtocolVersion();
             String uri = request.getRequestLine().getUri();
@@ -157,15 +140,15 @@ public class TestRedirects extends BasicServerTestBase {
         }
     }
 
-    private class RelativeRedirectService implements HttpRequestHandler {
-        
+    private static class RelativeRedirectService implements HttpRequestHandler {
+
         public RelativeRedirectService() {
             super();
         }
 
         public void handle(
-                final HttpRequest request, 
-                final HttpResponse response, 
+                final HttpRequest request,
+                final HttpResponse response,
                 final HttpContext context) throws HttpException, IOException {
             ProtocolVersion ver = request.getRequestLine().getProtocolVersion();
             String uri = request.getRequestLine().getUri();
@@ -182,15 +165,15 @@ public class TestRedirects extends BasicServerTestBase {
         }
     }
 
-    private class RelativeRedirectService2 implements HttpRequestHandler {
-        
+    private static class RelativeRedirectService2 implements HttpRequestHandler {
+
         public RelativeRedirectService2() {
             super();
         }
 
         public void handle(
-                final HttpRequest request, 
-                final HttpResponse response, 
+                final HttpRequest request,
+                final HttpResponse response,
                 final HttpContext context) throws HttpException, IOException {
             ProtocolVersion ver = request.getRequestLine().getProtocolVersion();
             String uri = request.getRequestLine().getUri();
@@ -207,17 +190,17 @@ public class TestRedirects extends BasicServerTestBase {
         }
     }
 
-    private class BogusRedirectService implements HttpRequestHandler {
+    private static class BogusRedirectService implements HttpRequestHandler {
         private String url;
-        
+
         public BogusRedirectService(String redirectUrl) {
             super();
             this.url = redirectUrl;
         }
 
         public void handle(
-                final HttpRequest request, 
-                final HttpResponse response, 
+                final HttpRequest request,
+                final HttpResponse response,
                 final HttpContext context) throws HttpException, IOException {
             ProtocolVersion ver = request.getRequestLine().getProtocolVersion();
             String uri = request.getRequestLine().getUri();
@@ -234,280 +217,309 @@ public class TestRedirects extends BasicServerTestBase {
         }
     }
 
+    @Test
     public void testBasicRedirect300() throws Exception {
-        int port = this.localServer.getServicePort();
-        String host = "localhost";
-        this.localServer.register("*", 
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
+        this.localServer.register("*",
                 new BasicRedirectService(host, port, HttpStatus.SC_MULTIPLE_CHOICES));
-        
-        DefaultHttpClient client = new DefaultHttpClient(); 
+
+        DefaultHttpClient client = new DefaultHttpClient();
         HttpContext context = new BasicHttpContext();
 
         HttpGet httpget = new HttpGet("/oldlocation/");
 
         HttpResponse response = client.execute(getServerHttp(), httpget, context);
-        HttpEntity e = response.getEntity();
-        if (e != null) {
-            e.consumeContent();
-        }
+        EntityUtils.consume(response.getEntity());
 
         HttpRequest reqWrapper = (HttpRequest) context.getAttribute(
                 ExecutionContext.HTTP_REQUEST);
-        
-        assertEquals(HttpStatus.SC_MULTIPLE_CHOICES, response.getStatusLine().getStatusCode());
-        assertEquals("/oldlocation/", reqWrapper.getRequestLine().getUri());
+
+        Assert.assertEquals(HttpStatus.SC_MULTIPLE_CHOICES, response.getStatusLine().getStatusCode());
+        Assert.assertEquals("/oldlocation/", reqWrapper.getRequestLine().getUri());
     }
 
+    @Test
     public void testBasicRedirect301() throws Exception {
-        int port = this.localServer.getServicePort();
-        String host = "localhost";
-        this.localServer.register("*", 
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
+        this.localServer.register("*",
                 new BasicRedirectService(host, port, HttpStatus.SC_MOVED_PERMANENTLY));
-        
-        DefaultHttpClient client = new DefaultHttpClient(); 
+
+        DefaultHttpClient client = new DefaultHttpClient();
         HttpContext context = new BasicHttpContext();
 
         HttpGet httpget = new HttpGet("/oldlocation/");
 
         HttpResponse response = client.execute(getServerHttp(), httpget, context);
-        HttpEntity e = response.getEntity();
-        if (e != null) {
-            e.consumeContent();
-        }
+        EntityUtils.consume(response.getEntity());
 
         HttpRequest reqWrapper = (HttpRequest) context.getAttribute(
                 ExecutionContext.HTTP_REQUEST);
         HttpHost targetHost = (HttpHost) context.getAttribute(
                 ExecutionContext.HTTP_TARGET_HOST);
 
-        assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
-        assertEquals("/newlocation/", reqWrapper.getRequestLine().getUri());
-        assertEquals(host, targetHost.getHostName());
-        assertEquals(port, targetHost.getPort());
+        Assert.assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
+        Assert.assertEquals("/newlocation/", reqWrapper.getRequestLine().getUri());
+        Assert.assertEquals(host, targetHost.getHostName());
+        Assert.assertEquals(port, targetHost.getPort());
     }
 
+    @Test
     public void testBasicRedirect302() throws Exception {
-        int port = this.localServer.getServicePort();
-        String host = "localhost";
-        this.localServer.register("*", 
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
+        this.localServer.register("*",
                 new BasicRedirectService(host, port, HttpStatus.SC_MOVED_TEMPORARILY));
-        
-        DefaultHttpClient client = new DefaultHttpClient(); 
+
+        DefaultHttpClient client = new DefaultHttpClient();
         HttpContext context = new BasicHttpContext();
 
         HttpGet httpget = new HttpGet("/oldlocation/");
 
         HttpResponse response = client.execute(getServerHttp(), httpget, context);
-        HttpEntity e = response.getEntity();
-        if (e != null) {
-            e.consumeContent();
-        }
+        EntityUtils.consume(response.getEntity());
 
         HttpRequest reqWrapper = (HttpRequest) context.getAttribute(
                 ExecutionContext.HTTP_REQUEST);
         HttpHost targetHost = (HttpHost) context.getAttribute(
                 ExecutionContext.HTTP_TARGET_HOST);
 
-        assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
-        assertEquals("/newlocation/", reqWrapper.getRequestLine().getUri());
-        assertEquals(host, targetHost.getHostName());
-        assertEquals(port, targetHost.getPort());
+        Assert.assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
+        Assert.assertEquals("/newlocation/", reqWrapper.getRequestLine().getUri());
+        Assert.assertEquals(host, targetHost.getHostName());
+        Assert.assertEquals(port, targetHost.getPort());
     }
 
+    @Test
+    public void testBasicRedirect302NoLocation() throws Exception {
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
+        this.localServer.register("*", new HttpRequestHandler() {
+
+            public void handle(
+                    final HttpRequest request,
+                    final HttpResponse response,
+                    final HttpContext context) throws HttpException, IOException {
+                response.setStatusCode(HttpStatus.SC_MOVED_TEMPORARILY);
+            }
+
+        });
+
+        DefaultHttpClient client = new DefaultHttpClient();
+        HttpContext context = new BasicHttpContext();
+
+        HttpGet httpget = new HttpGet("/oldlocation/");
+
+        HttpResponse response = client.execute(getServerHttp(), httpget, context);
+        EntityUtils.consume(response.getEntity());
+
+        HttpRequest reqWrapper = (HttpRequest) context.getAttribute(
+                ExecutionContext.HTTP_REQUEST);
+        HttpHost targetHost = (HttpHost) context.getAttribute(
+                ExecutionContext.HTTP_TARGET_HOST);
+
+        Assert.assertEquals(HttpStatus.SC_MOVED_TEMPORARILY, response.getStatusLine().getStatusCode());
+        Assert.assertEquals("/oldlocation/", reqWrapper.getRequestLine().getUri());
+        Assert.assertEquals(host, targetHost.getHostName());
+        Assert.assertEquals(port, targetHost.getPort());
+    }
+
+    @Test
     public void testBasicRedirect303() throws Exception {
-        int port = this.localServer.getServicePort();
-        String host = "localhost";
-        this.localServer.register("*", 
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
+        this.localServer.register("*",
                 new BasicRedirectService(host, port, HttpStatus.SC_SEE_OTHER));
-        
-        DefaultHttpClient client = new DefaultHttpClient(); 
+
+        DefaultHttpClient client = new DefaultHttpClient();
         HttpContext context = new BasicHttpContext();
 
         HttpGet httpget = new HttpGet("/oldlocation/");
 
         HttpResponse response = client.execute(getServerHttp(), httpget, context);
-        HttpEntity e = response.getEntity();
-        if (e != null) {
-            e.consumeContent();
-        }
+        EntityUtils.consume(response.getEntity());
 
         HttpRequest reqWrapper = (HttpRequest) context.getAttribute(
                 ExecutionContext.HTTP_REQUEST);
         HttpHost targetHost = (HttpHost) context.getAttribute(
                 ExecutionContext.HTTP_TARGET_HOST);
 
-        assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
-        assertEquals("/newlocation/", reqWrapper.getRequestLine().getUri());
-        assertEquals(host, targetHost.getHostName());
-        assertEquals(port, targetHost.getPort());
+        Assert.assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
+        Assert.assertEquals("/newlocation/", reqWrapper.getRequestLine().getUri());
+        Assert.assertEquals(host, targetHost.getHostName());
+        Assert.assertEquals(port, targetHost.getPort());
     }
 
+    @Test
     public void testBasicRedirect304() throws Exception {
-        int port = this.localServer.getServicePort();
-        String host = "localhost";
-        this.localServer.register("*", 
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
+        this.localServer.register("*",
                 new BasicRedirectService(host, port, HttpStatus.SC_NOT_MODIFIED));
-        
-        DefaultHttpClient client = new DefaultHttpClient(); 
+
+        DefaultHttpClient client = new DefaultHttpClient();
         HttpContext context = new BasicHttpContext();
 
         HttpGet httpget = new HttpGet("/oldlocation/");
 
         HttpResponse response = client.execute(getServerHttp(), httpget, context);
-        HttpEntity e = response.getEntity();
-        if (e != null) {
-            e.consumeContent();
-        }
+        EntityUtils.consume(response.getEntity());
 
         HttpRequest reqWrapper = (HttpRequest) context.getAttribute(
                 ExecutionContext.HTTP_REQUEST);
-        
-        assertEquals(HttpStatus.SC_NOT_MODIFIED, response.getStatusLine().getStatusCode());
-        assertEquals("/oldlocation/", reqWrapper.getRequestLine().getUri());
+
+        Assert.assertEquals(HttpStatus.SC_NOT_MODIFIED, response.getStatusLine().getStatusCode());
+        Assert.assertEquals("/oldlocation/", reqWrapper.getRequestLine().getUri());
     }
 
+    @Test
     public void testBasicRedirect305() throws Exception {
-        int port = this.localServer.getServicePort();
-        String host = "localhost";
-        this.localServer.register("*", 
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
+        this.localServer.register("*",
                 new BasicRedirectService(host, port, HttpStatus.SC_USE_PROXY));
-        
-        DefaultHttpClient client = new DefaultHttpClient(); 
+
+        DefaultHttpClient client = new DefaultHttpClient();
         HttpContext context = new BasicHttpContext();
 
         HttpGet httpget = new HttpGet("/oldlocation/");
 
         HttpResponse response = client.execute(getServerHttp(), httpget, context);
-        HttpEntity e = response.getEntity();
-        if (e != null) {
-            e.consumeContent();
-        }
+        EntityUtils.consume(response.getEntity());
 
         HttpRequest reqWrapper = (HttpRequest) context.getAttribute(
                 ExecutionContext.HTTP_REQUEST);
-        
-        assertEquals(HttpStatus.SC_USE_PROXY, response.getStatusLine().getStatusCode());
-        assertEquals("/oldlocation/", reqWrapper.getRequestLine().getUri());
+
+        Assert.assertEquals(HttpStatus.SC_USE_PROXY, response.getStatusLine().getStatusCode());
+        Assert.assertEquals("/oldlocation/", reqWrapper.getRequestLine().getUri());
     }
 
+    @Test
     public void testBasicRedirect307() throws Exception {
-        int port = this.localServer.getServicePort();
-        String host = "localhost";
-        this.localServer.register("*", 
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
+        this.localServer.register("*",
                 new BasicRedirectService(host, port, HttpStatus.SC_TEMPORARY_REDIRECT));
-        
-        DefaultHttpClient client = new DefaultHttpClient(); 
+
+        DefaultHttpClient client = new DefaultHttpClient();
         HttpContext context = new BasicHttpContext();
 
         HttpGet httpget = new HttpGet("/oldlocation/");
 
         HttpResponse response = client.execute(getServerHttp(), httpget, context);
-        HttpEntity e = response.getEntity();
-        if (e != null) {
-            e.consumeContent();
-        }
+        EntityUtils.consume(response.getEntity());
 
         HttpRequest reqWrapper = (HttpRequest) context.getAttribute(
                 ExecutionContext.HTTP_REQUEST);
         HttpHost targetHost = (HttpHost) context.getAttribute(
                 ExecutionContext.HTTP_TARGET_HOST);
 
-        assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
-        assertEquals("/newlocation/", reqWrapper.getRequestLine().getUri());
-        assertEquals(host, targetHost.getHostName());
-        assertEquals(port, targetHost.getPort());
+        Assert.assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
+        Assert.assertEquals("/newlocation/", reqWrapper.getRequestLine().getUri());
+        Assert.assertEquals(host, targetHost.getHostName());
+        Assert.assertEquals(port, targetHost.getPort());
     }
 
+    @Test(expected=ClientProtocolException.class)
     public void testMaxRedirectCheck() throws Exception {
         this.localServer.register("*", new CircularRedirectService());
 
-        DefaultHttpClient client = new DefaultHttpClient(); 
+        DefaultHttpClient client = new DefaultHttpClient();
         client.getParams().setBooleanParameter(ClientPNames.ALLOW_CIRCULAR_REDIRECTS, true);
         client.getParams().setIntParameter(ClientPNames.MAX_REDIRECTS, 5);
 
         HttpGet httpget = new HttpGet("/circular-oldlocation/");
-
         try {
             client.execute(getServerHttp(), httpget);
-            fail("ClientProtocolException exception should have been thrown");
         } catch (ClientProtocolException e) {
-            assertTrue(e.getCause() instanceof RedirectException);
+            Assert.assertTrue(e.getCause() instanceof RedirectException);
+            throw e;
         }
     }
 
+    @Test(expected=ClientProtocolException.class)
     public void testCircularRedirect() throws Exception {
         this.localServer.register("*", new CircularRedirectService());
 
-        DefaultHttpClient client = new DefaultHttpClient(); 
+        DefaultHttpClient client = new DefaultHttpClient();
         client.getParams().setBooleanParameter(ClientPNames.ALLOW_CIRCULAR_REDIRECTS, false);
 
         HttpGet httpget = new HttpGet("/circular-oldlocation/");
 
         try {
             client.execute(getServerHttp(), httpget);
-            fail("ClientProtocolException exception should have been thrown");
         } catch (ClientProtocolException e) {
-            assertTrue(e.getCause() instanceof CircularRedirectException);
+            Assert.assertTrue(e.getCause() instanceof CircularRedirectException);
+            throw e;
         }
     }
 
+    @Test
     public void testPostNoRedirect() throws Exception {
-        int port = this.localServer.getServicePort();
-        String host = "localhost";
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
         this.localServer.register("*", new BasicRedirectService(host, port));
 
-        DefaultHttpClient client = new DefaultHttpClient(); 
+        DefaultHttpClient client = new DefaultHttpClient();
         HttpContext context = new BasicHttpContext();
-        
+
         HttpPost httppost = new HttpPost("/oldlocation/");
         httppost.setEntity(new StringEntity("stuff"));
 
         HttpResponse response = client.execute(getServerHttp(), httppost, context);
-        HttpEntity e = response.getEntity();
-        if (e != null) {
-            e.consumeContent();
-        }
-        
+        EntityUtils.consume(response.getEntity());
+
         HttpRequest reqWrapper = (HttpRequest) context.getAttribute(
                 ExecutionContext.HTTP_REQUEST);
 
-        assertEquals(HttpStatus.SC_MOVED_TEMPORARILY, response.getStatusLine().getStatusCode());
-        assertEquals("/oldlocation/", reqWrapper.getRequestLine().getUri());
-        assertEquals("POST", reqWrapper.getRequestLine().getMethod());
+        Assert.assertEquals(HttpStatus.SC_MOVED_TEMPORARILY, response.getStatusLine().getStatusCode());
+        Assert.assertEquals("/oldlocation/", reqWrapper.getRequestLine().getUri());
+        Assert.assertEquals("POST", reqWrapper.getRequestLine().getMethod());
     }
 
+    @Test
     public void testPostRedirectSeeOther() throws Exception {
-        int port = this.localServer.getServicePort();
-        String host = "localhost";
-        this.localServer.register("*", new BasicRedirectService(host, port, 
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
+        this.localServer.register("*", new BasicRedirectService(host, port,
                 HttpStatus.SC_SEE_OTHER));
 
-        DefaultHttpClient client = new DefaultHttpClient(); 
+        DefaultHttpClient client = new DefaultHttpClient();
         HttpContext context = new BasicHttpContext();
-        
+
         HttpPost httppost = new HttpPost("/oldlocation/");
         httppost.setEntity(new StringEntity("stuff"));
 
         HttpResponse response = client.execute(getServerHttp(), httppost, context);
-        HttpEntity e = response.getEntity();
-        if (e != null) {
-            e.consumeContent();
-        }
-        
+        EntityUtils.consume(response.getEntity());
+
         HttpRequest reqWrapper = (HttpRequest) context.getAttribute(
                 ExecutionContext.HTTP_REQUEST);
 
-        assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
-        assertEquals("/newlocation/", reqWrapper.getRequestLine().getUri());
-        assertEquals("GET", reqWrapper.getRequestLine().getMethod());
+        Assert.assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
+        Assert.assertEquals("/newlocation/", reqWrapper.getRequestLine().getUri());
+        Assert.assertEquals("GET", reqWrapper.getRequestLine().getMethod());
     }
 
+    @Test
     public void testRelativeRedirect() throws Exception {
-        int port = this.localServer.getServicePort();
-        String host = this.localServer.getServiceHostName();
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
         this.localServer.register("*", new RelativeRedirectService());
 
-        DefaultHttpClient client = new DefaultHttpClient(); 
+        DefaultHttpClient client = new DefaultHttpClient();
         HttpContext context = new BasicHttpContext();
 
         client.getParams().setBooleanParameter(
@@ -515,28 +527,27 @@ public class TestRedirects extends BasicServerTestBase {
         HttpGet httpget = new HttpGet("/oldlocation/");
 
         HttpResponse response = client.execute(getServerHttp(), httpget, context);
-        HttpEntity e = response.getEntity();
-        if (e != null) {
-            e.consumeContent();
-        }
-        
+        EntityUtils.consume(response.getEntity());
+
         HttpRequest reqWrapper = (HttpRequest) context.getAttribute(
                 ExecutionContext.HTTP_REQUEST);
         HttpHost targetHost = (HttpHost) context.getAttribute(
                 ExecutionContext.HTTP_TARGET_HOST);
 
-        assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
-        assertEquals("/relativelocation/", reqWrapper.getRequestLine().getUri());
-        assertEquals(host, targetHost.getHostName());
-        assertEquals(port, targetHost.getPort());
+        Assert.assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
+        Assert.assertEquals("/relativelocation/", reqWrapper.getRequestLine().getUri());
+        Assert.assertEquals(host, targetHost.getHostName());
+        Assert.assertEquals(port, targetHost.getPort());
     }
 
+    @Test
     public void testRelativeRedirect2() throws Exception {
-        int port = this.localServer.getServicePort();
-        String host = this.localServer.getServiceHostName();
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
         this.localServer.register("*", new RelativeRedirectService2());
 
-        DefaultHttpClient client = new DefaultHttpClient(); 
+        DefaultHttpClient client = new DefaultHttpClient();
         HttpContext context = new BasicHttpContext();
 
         client.getParams().setBooleanParameter(
@@ -544,26 +555,24 @@ public class TestRedirects extends BasicServerTestBase {
         HttpGet httpget = new HttpGet("/test/oldlocation");
 
         HttpResponse response = client.execute(getServerHttp(), httpget, context);
-        HttpEntity e = response.getEntity();
-        if (e != null) {
-            e.consumeContent();
-        }
-        
+        EntityUtils.consume(response.getEntity());
+
         HttpRequest reqWrapper = (HttpRequest) context.getAttribute(
                 ExecutionContext.HTTP_REQUEST);
         HttpHost targetHost = (HttpHost) context.getAttribute(
                 ExecutionContext.HTTP_TARGET_HOST);
 
-        assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
-        assertEquals("/test/relativelocation", reqWrapper.getRequestLine().getUri());
-        assertEquals(host, targetHost.getHostName());
-        assertEquals(port, targetHost.getPort());
+        Assert.assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
+        Assert.assertEquals("/test/relativelocation", reqWrapper.getRequestLine().getUri());
+        Assert.assertEquals(host, targetHost.getHostName());
+        Assert.assertEquals(port, targetHost.getPort());
     }
 
+    @Test(expected=ClientProtocolException.class)
     public void testRejectRelativeRedirect() throws Exception {
         this.localServer.register("*", new RelativeRedirectService());
 
-        DefaultHttpClient client = new DefaultHttpClient(); 
+        DefaultHttpClient client = new DefaultHttpClient();
 
         client.getParams().setBooleanParameter(
                 ClientPNames.REJECT_RELATIVE_REDIRECT, true);
@@ -571,117 +580,111 @@ public class TestRedirects extends BasicServerTestBase {
 
         try {
             client.execute(getServerHttp(), httpget);
-            fail("ClientProtocolException exception should have been thrown");
         } catch (ClientProtocolException e) {
-            assertTrue(e.getCause() instanceof ProtocolException);
-            // expected
+            Assert.assertTrue(e.getCause() instanceof ProtocolException);
+            throw e;
         }
     }
 
+    @Test(expected=IllegalStateException.class)
     public void testRejectBogusRedirectLocation() throws Exception {
         this.localServer.register("*", new BogusRedirectService("xxx://bogus"));
 
-        DefaultHttpClient client = new DefaultHttpClient(); 
+        DefaultHttpClient client = new DefaultHttpClient();
 
         HttpGet httpget = new HttpGet("/oldlocation/");
 
-        try {
-            client.execute(getServerHttp(), httpget);
-            fail("IllegalStateException should have been thrown");
-        } catch (IllegalStateException e) {
-            // expected
-        }
+        client.execute(getServerHttp(), httpget);
     }
 
+    @Test(expected=ClientProtocolException.class)
     public void testRejectInvalidRedirectLocation() throws Exception {
-        String host = "localhost";
-        int port = this.localServer.getServicePort();
-        this.localServer.register("*", 
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
+        this.localServer.register("*",
                 new BogusRedirectService("http://"+ host +":"+ port +"/newlocation/?p=I have spaces"));
 
-        DefaultHttpClient client = new DefaultHttpClient(); 
+        DefaultHttpClient client = new DefaultHttpClient();
 
         HttpGet httpget = new HttpGet("/oldlocation/");
 
         try {
             client.execute(getServerHttp(), httpget);
-            fail("ClientProtocolException should have been thrown");
         } catch (ClientProtocolException e) {
-            assertTrue(e.getCause() instanceof ProtocolException);
-            // expected
+            Assert.assertTrue(e.getCause() instanceof ProtocolException);
+            throw e;
         }
     }
 
+    @Test
     public void testRedirectWithCookie() throws Exception {
-        String host = "localhost";
-        int port = this.localServer.getServicePort();
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
 
-        this.localServer.register("*", 
+        this.localServer.register("*",
                 new BasicRedirectService(host, port));
 
-        DefaultHttpClient client = new DefaultHttpClient(); 
-        
+        DefaultHttpClient client = new DefaultHttpClient();
+
         CookieStore cookieStore = new BasicCookieStore();
         client.setCookieStore(cookieStore);
-        
+
         BasicClientCookie cookie = new BasicClientCookie("name", "value");
-        cookie.setDomain("localhost");
+        cookie.setDomain(host);
         cookie.setPath("/");
-        
+
         cookieStore.addCookie(cookie);
 
         HttpContext context = new BasicHttpContext();
         HttpGet httpget = new HttpGet("/oldlocation/");
 
-        
+
         HttpResponse response = client.execute(getServerHttp(), httpget, context);
-        HttpEntity e = response.getEntity();
-        if (e != null) {
-            e.consumeContent();
-        }
-        
+        EntityUtils.consume(response.getEntity());
+
         HttpRequest reqWrapper = (HttpRequest) context.getAttribute(
                 ExecutionContext.HTTP_REQUEST);
 
-        assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
-        assertEquals("/newlocation/", reqWrapper.getRequestLine().getUri());
+        Assert.assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
+        Assert.assertEquals("/newlocation/", reqWrapper.getRequestLine().getUri());
 
         Header[] headers = reqWrapper.getHeaders(SM.COOKIE);
-        assertEquals("There can only be one (cookie)", 1, headers.length);            
+        Assert.assertEquals("There can only be one (cookie)", 1, headers.length);
     }
 
+    @Test
     public void testDefaultHeadersRedirect() throws Exception {
-        String host = "localhost";
-        int port = this.localServer.getServicePort();
+        InetSocketAddress address = this.localServer.getServiceAddress();
+        int port = address.getPort();
+        String host = address.getHostName();
 
-        this.localServer.register("*", 
+        this.localServer.register("*",
                 new BasicRedirectService(host, port));
 
-        DefaultHttpClient client = new DefaultHttpClient(); 
+        DefaultHttpClient client = new DefaultHttpClient();
         HttpContext context = new BasicHttpContext();
 
         List<Header> defaultHeaders = new ArrayList<Header>(1);
         defaultHeaders.add(new BasicHeader(HTTP.USER_AGENT, "my-test-client"));
-        
+
         client.getParams().setParameter(ClientPNames.DEFAULT_HEADERS, defaultHeaders);
-        
+
         HttpGet httpget = new HttpGet("/oldlocation/");
 
-        
+
         HttpResponse response = client.execute(getServerHttp(), httpget, context);
-        HttpEntity e = response.getEntity();
-        if (e != null) {
-            e.consumeContent();
-        }
-        
+        EntityUtils.consume(response.getEntity());
+
         HttpRequest reqWrapper = (HttpRequest) context.getAttribute(
                 ExecutionContext.HTTP_REQUEST);
 
-        assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
-        assertEquals("/newlocation/", reqWrapper.getRequestLine().getUri());
+        Assert.assertEquals(HttpStatus.SC_OK, response.getStatusLine().getStatusCode());
+        Assert.assertEquals("/newlocation/", reqWrapper.getRequestLine().getUri());
 
         Header header = reqWrapper.getFirstHeader(HTTP.USER_AGENT);
-        assertEquals("my-test-client", header.getValue());            
+        Assert.assertEquals("my-test-client", header.getValue());
     }
 
 }
