@@ -27,22 +27,18 @@
 
 package org.apache.http.conn.routing;
 
-
 import java.net.InetAddress;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import org.apache.http.HttpHost;
 import org.apache.http.conn.routing.RouteInfo.TunnelType;
 import org.apache.http.conn.routing.RouteInfo.LayerType;
-
+import org.junit.Assert;
+import org.junit.Test;
 
 /**
- * Tests for <code>BasicRouteDirector</code>.
+ * Tests for {@link BasicRouteDirector}.
  */
-public class TestRouteDirector extends TestCase {
+public class TestRouteDirector {
 
     // a selection of constants for generating routes
     public final static
@@ -83,35 +79,14 @@ public class TestRouteDirector extends TestCase {
         }
     }
 
-
-    public TestRouteDirector(String testName) {
-        super(testName);
-    }
-
-    public static void main(String args[]) {
-        String[] testCaseName = { TestRouteDirector.class.getName() };
-        junit.textui.TestRunner.main(testCaseName);
-    }
-
-    public static Test suite() {
-        return new TestSuite(TestRouteDirector.class);
-    }
-
-
+    @Test(expected=IllegalArgumentException.class)
     public void testIllegal() {
-
         HttpRouteDirector rowdy = new BasicRouteDirector();
         HttpRoute route = new HttpRoute(TARGET1);
-
-        try {
-            rowdy.nextStep(null, route);
-            fail("null argument not detected");
-        } catch (IllegalArgumentException iax) {
-            // expected
-        }
+        rowdy.nextStep(null, route);
     }
 
-
+    @Test
     public void testDirect() {
 
         HttpRouteDirector rowdy = new BasicRouteDirector();
@@ -120,31 +95,31 @@ public class TestRouteDirector extends TestCase {
         HttpRoute route1p1 = new HttpRoute(TARGET1, null, PROXY1, false);
 
         int step = rowdy.nextStep(route1, null);
-        assertEquals("wrong step to route1",
+        Assert.assertEquals("wrong step to route1",
                      HttpRouteDirector.CONNECT_TARGET, step);
 
         step = rowdy.nextStep(route2, null);
-        assertEquals("wrong step to route2",
+        Assert.assertEquals("wrong step to route2",
                      HttpRouteDirector.CONNECT_TARGET, step);
 
         step = rowdy.nextStep(route1, route1);
-        assertEquals("complete route1 not detected",
+        Assert.assertEquals("complete route1 not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route2, route2);
-        assertEquals("complete route2 not detected",
+        Assert.assertEquals("complete route2 not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route1, route2);
-        assertEquals("unreachable target not detected",
+        Assert.assertEquals("unreachable target not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
         step = rowdy.nextStep(route1, route1p1);
-        assertEquals("invalid proxy not detected",
+        Assert.assertEquals("invalid proxy not detected",
                      HttpRouteDirector.UNREACHABLE, step);
     }
 
-
+    @Test
     public void testProxy() {
 
         HttpRouteDirector rowdy = new BasicRouteDirector();
@@ -155,43 +130,43 @@ public class TestRouteDirector extends TestCase {
         HttpRoute route1   = new HttpRoute(TARGET1);
 
         int step = rowdy.nextStep(route1p1, null);
-        assertEquals("wrong step to route1p1",
+        Assert.assertEquals("wrong step to route1p1",
                      HttpRouteDirector.CONNECT_PROXY, step);
 
         step = rowdy.nextStep(route1p2, null);
-        assertEquals("wrong step to route1p2",
+        Assert.assertEquals("wrong step to route1p2",
                      HttpRouteDirector.CONNECT_PROXY, step);
 
         step = rowdy.nextStep(route1p1, route1p1);
-        assertEquals("complete route1p1 not detected",
+        Assert.assertEquals("complete route1p1 not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route1p2, route1p2);
-        assertEquals("complete route1p2 not detected",
+        Assert.assertEquals("complete route1p2 not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route2p1, route2p1);
-        assertEquals("complete route2p1 not detected",
+        Assert.assertEquals("complete route2p1 not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route1p1, route1p2);
-        assertEquals("unreachable route1p1 via route1p2 not detected",
+        Assert.assertEquals("unreachable route1p1 via route1p2 not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
         step = rowdy.nextStep(route1p1, route2p1);
-        assertEquals("unreachable route1p1 via route2p1 not detected",
+        Assert.assertEquals("unreachable route1p1 via route2p1 not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
         step = rowdy.nextStep(route1p1, route0);
-        assertEquals("unreachable route1p1 via route0 not detected",
+        Assert.assertEquals("unreachable route1p1 via route0 not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
         step = rowdy.nextStep(route1p1, route1);
-        assertEquals("unreachable route1p1 via route1 not detected",
+        Assert.assertEquals("unreachable route1p1 via route1 not detected",
                      HttpRouteDirector.UNREACHABLE, step);
     }
 
-
+    @Test
     public void testProxyChain() {
         HttpHost[] chainA = { PROXY1 };
         HttpHost[] chainB = { PROXY1, PROXY2 };
@@ -208,45 +183,45 @@ public class TestRouteDirector extends TestCase {
                                             TunnelType.PLAIN, LayerType.PLAIN);
 
         int step = rowdy.nextStep(route1cA, null);
-        assertEquals("wrong step to route1cA",
+        Assert.assertEquals("wrong step to route1cA",
                      HttpRouteDirector.CONNECT_PROXY, step);
 
         step = rowdy.nextStep(route1cB, null);
-        assertEquals("wrong step to route1cB",
+        Assert.assertEquals("wrong step to route1cB",
                      HttpRouteDirector.CONNECT_PROXY, step);
 
         step = rowdy.nextStep(route1cC, null);
-        assertEquals("wrong step to route1cC",
+        Assert.assertEquals("wrong step to route1cC",
                      HttpRouteDirector.CONNECT_PROXY, step);
 
         step = rowdy.nextStep(route1cD, null);
-        assertEquals("wrong step to route1cD",
+        Assert.assertEquals("wrong step to route1cD",
                      HttpRouteDirector.CONNECT_PROXY, step);
 
 
         step = rowdy.nextStep(route1cB, route1cA);
-        assertEquals("wrong step to route 1cB from 1cA",
+        Assert.assertEquals("wrong step to route 1cB from 1cA",
                      HttpRouteDirector.TUNNEL_PROXY, step);
 
         step = rowdy.nextStep(route1cB, route1cB);
-        assertEquals("complete route 1cB not detected",
+        Assert.assertEquals("complete route 1cB not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route1cB, route1cC);
-        assertEquals("unreachable route 1cB from 1cC not detected",
+        Assert.assertEquals("unreachable route 1cB from 1cC not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
         step = rowdy.nextStep(route1cB, route1cD);
-        assertEquals("unreachable route 1cB from 1cD not detected",
+        Assert.assertEquals("unreachable route 1cB from 1cD not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
 
         step = rowdy.nextStep(route1cA, route1cB);
-        assertEquals("unreachable route 1cA from 1cB not detected",
+        Assert.assertEquals("unreachable route 1cA from 1cB not detected",
                      HttpRouteDirector.UNREACHABLE, step);
     }
 
-
+    @Test
     public void testLocalDirect() {
 
         HttpRouteDirector rowdy = new BasicRouteDirector();
@@ -256,65 +231,65 @@ public class TestRouteDirector extends TestCase {
         HttpRoute route1l00 = new HttpRoute(TARGET1, null, false);
 
         int step = rowdy.nextStep(route1l41, null);
-        assertEquals("wrong step to route1l41",
+        Assert.assertEquals("wrong step to route1l41",
                      HttpRouteDirector.CONNECT_TARGET, step);
 
         step = rowdy.nextStep(route1l42, null);
-        assertEquals("wrong step to route1l42",
+        Assert.assertEquals("wrong step to route1l42",
                      HttpRouteDirector.CONNECT_TARGET, step);
 
         step = rowdy.nextStep(route1l61, null);
-        assertEquals("wrong step to route1l61",
+        Assert.assertEquals("wrong step to route1l61",
                      HttpRouteDirector.CONNECT_TARGET, step);
 
         step = rowdy.nextStep(route1l00, null);
-        assertEquals("wrong step to route1l00",
+        Assert.assertEquals("wrong step to route1l00",
                      HttpRouteDirector.CONNECT_TARGET, step);
 
         step = rowdy.nextStep(route1l41, route1l41);
-        assertEquals("complete route1l41 not detected",
+        Assert.assertEquals("complete route1l41 not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route1l42, route1l42);
-        assertEquals("complete route1l42 not detected",
+        Assert.assertEquals("complete route1l42 not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route1l61, route1l61);
-        assertEquals("complete route1l61 not detected",
+        Assert.assertEquals("complete route1l61 not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route1l00, route1l00);
-        assertEquals("complete route1l00 not detected",
+        Assert.assertEquals("complete route1l00 not detected",
                      HttpRouteDirector.COMPLETE, step);
 
 
         step = rowdy.nextStep(route1l41, route1l42);
-        assertEquals("unreachable route1l41 via route1l42 not detected",
+        Assert.assertEquals("unreachable route1l41 via route1l42 not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
         step = rowdy.nextStep(route1l41, route1l61);
-        assertEquals("unreachable route1l41 via route1l61 not detected",
+        Assert.assertEquals("unreachable route1l41 via route1l61 not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
         step = rowdy.nextStep(route1l41, route1l00);
-        assertEquals("unreachable route1l41 via route1l00 not detected",
+        Assert.assertEquals("unreachable route1l41 via route1l00 not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
 
         step = rowdy.nextStep(route1l00, route1l41);
-        assertEquals("complete route1l00 as route1l41 not detected",
+        Assert.assertEquals("complete route1l00 as route1l41 not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route1l00, route1l42);
-        assertEquals("complete route1l00 as route1l42 not detected",
+        Assert.assertEquals("complete route1l00 as route1l42 not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route1l00, route1l61);
-        assertEquals("complete route1l00 as route1l61 not detected",
+        Assert.assertEquals("complete route1l00 as route1l61 not detected",
                      HttpRouteDirector.COMPLETE, step);
     }
 
-
+    @Test
     public void testDirectSecure() {
 
         HttpRouteDirector rowdy = new BasicRouteDirector();
@@ -324,35 +299,35 @@ public class TestRouteDirector extends TestCase {
         HttpRoute route1p1s = new HttpRoute(TARGET1, null, PROXY1, true);
 
         int step = rowdy.nextStep(route1u, null);
-        assertEquals("wrong step to route1u",
+        Assert.assertEquals("wrong step to route1u",
                      HttpRouteDirector.CONNECT_TARGET, step);
 
         step = rowdy.nextStep(route1s, null);
-        assertEquals("wrong step to route1s",
+        Assert.assertEquals("wrong step to route1s",
                      HttpRouteDirector.CONNECT_TARGET, step);
 
         // unrequested security is currently not tolerated
         step = rowdy.nextStep(route1u, route1s);
-        assertEquals("unreachable route 1u from 1s not detected",
+        Assert.assertEquals("unreachable route 1u from 1s not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
         // secure layering of direct connections is currently not supported
         step = rowdy.nextStep(route1s, route1u);
-        assertEquals("unreachable route 1s from 1u not detected",
+        Assert.assertEquals("unreachable route 1s from 1u not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
 
 
         step = rowdy.nextStep(route1s, route1p1u);
-        assertEquals("unreachable route 1s from 1p1u not detected",
+        Assert.assertEquals("unreachable route 1s from 1p1u not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
         step = rowdy.nextStep(route1s, route1p1s);
-        assertEquals("unreachable route 1s from 1p1s not detected",
+        Assert.assertEquals("unreachable route 1s from 1p1s not detected",
                      HttpRouteDirector.UNREACHABLE, step);
     }
 
-
+    @Test
     public void testProxyTLS() {
 
         HttpRouteDirector rowdy = new BasicRouteDirector();
@@ -378,118 +353,118 @@ public class TestRouteDirector extends TestCase {
         // we don't consider a route that is layered but not tunnelled
 
         int step = rowdy.nextStep(route1, null);
-        assertEquals("wrong step to route1",
+        Assert.assertEquals("wrong step to route1",
                      HttpRouteDirector.CONNECT_PROXY, step);
 
         step = rowdy.nextStep(route1t, null);
-        assertEquals("wrong step to route1t",
+        Assert.assertEquals("wrong step to route1t",
                      HttpRouteDirector.CONNECT_PROXY, step);
 
         step = rowdy.nextStep(route1tl, null);
-        assertEquals("wrong step to route1tl",
+        Assert.assertEquals("wrong step to route1tl",
                      HttpRouteDirector.CONNECT_PROXY, step);
 
         step = rowdy.nextStep(route1s, null);
-        assertEquals("wrong step to route1s",
+        Assert.assertEquals("wrong step to route1s",
                      HttpRouteDirector.CONNECT_PROXY, step);
 
         step = rowdy.nextStep(route1ts, null);
-        assertEquals("wrong step to route1ts",
+        Assert.assertEquals("wrong step to route1ts",
                      HttpRouteDirector.CONNECT_PROXY, step);
 
         step = rowdy.nextStep(route1tls, null);
-        assertEquals("wrong step to route1tls",
+        Assert.assertEquals("wrong step to route1tls",
                      HttpRouteDirector.CONNECT_PROXY, step);
 
 
         step = rowdy.nextStep(route1, route1);
-        assertEquals("complete route1 not detected",
+        Assert.assertEquals("complete route1 not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route1t, route1t);
-        assertEquals("complete route1t not detected",
+        Assert.assertEquals("complete route1t not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route1tl, route1tl);
-        assertEquals("complete route1tl not detected",
+        Assert.assertEquals("complete route1tl not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route1s, route1s);
-        assertEquals("complete route1s not detected",
+        Assert.assertEquals("complete route1s not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route1ts, route1ts);
-        assertEquals("complete route1ts not detected",
+        Assert.assertEquals("complete route1ts not detected",
                      HttpRouteDirector.COMPLETE, step);
 
         step = rowdy.nextStep(route1tls, route1tls);
-        assertEquals("complete route1tls not detected",
+        Assert.assertEquals("complete route1tls not detected",
                      HttpRouteDirector.COMPLETE, step);
 
 
 
         step = rowdy.nextStep(route1, route1t);
-        assertEquals("unreachable route1 from 1t not detected",
+        Assert.assertEquals("unreachable route1 from 1t not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
         step = rowdy.nextStep(route1, route1tl);
-        assertEquals("unreachable route1 from 1tl not detected",
+        Assert.assertEquals("unreachable route1 from 1tl not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
         // unrequested security is currently not tolerated
         step = rowdy.nextStep(route1, route1s);
-        assertEquals("unreachable route1 from 1s not detected",
+        Assert.assertEquals("unreachable route1 from 1s not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
         step = rowdy.nextStep(route1, route1ts);
-        assertEquals("unreachable route1 from 1ts not detected",
+        Assert.assertEquals("unreachable route1 from 1ts not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
         step = rowdy.nextStep(route1, route1tls);
-        assertEquals("unreachable route1 from 1tls not detected",
+        Assert.assertEquals("unreachable route1 from 1tls not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
 
         // securing requires layering
         step = rowdy.nextStep(route1s, route1);
-        assertEquals("unreachable route1s from 1 not detected",
+        Assert.assertEquals("unreachable route1s from 1 not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
         // securing requires layering, and multiple layers are not supported
         step = rowdy.nextStep(route1tls, route1tl);
-        assertEquals("unreachable route1tls from 1tl not detected",
+        Assert.assertEquals("unreachable route1tls from 1tl not detected",
                      HttpRouteDirector.UNREACHABLE, step);
 
 
         // cases where tunnelling to the target is required
         step = rowdy.nextStep(route1t, route1);
-        assertEquals("wrong step to route1t from 1",
+        Assert.assertEquals("wrong step to route1t from 1",
                      HttpRouteDirector.TUNNEL_TARGET, step);
 
         step = rowdy.nextStep(route1tl, route1);
-        assertEquals("wrong step to route1tl from 1",
+        Assert.assertEquals("wrong step to route1tl from 1",
                      HttpRouteDirector.TUNNEL_TARGET, step);
 
         step = rowdy.nextStep(route1tls, route1);
-        assertEquals("wrong step to route1tls from 1",
+        Assert.assertEquals("wrong step to route1tls from 1",
                      HttpRouteDirector.TUNNEL_TARGET, step);
 
 
         // cases where layering on the tunnel is required
         step = rowdy.nextStep(route1tl, route1t);
-        assertEquals("wrong step to route1tl from 1t",
+        Assert.assertEquals("wrong step to route1tl from 1t",
                      HttpRouteDirector.LAYER_PROTOCOL, step);
 
         step = rowdy.nextStep(route1tl, route1ts);
-        assertEquals("wrong step to route1tl from 1ts",
+        Assert.assertEquals("wrong step to route1tl from 1ts",
                      HttpRouteDirector.LAYER_PROTOCOL, step);
 
         step = rowdy.nextStep(route1tls, route1t);
-        assertEquals("wrong step to route1tls from 1t",
+        Assert.assertEquals("wrong step to route1tls from 1t",
                      HttpRouteDirector.LAYER_PROTOCOL, step);
 
         step = rowdy.nextStep(route1tls, route1ts);
-        assertEquals("wrong step to route1tls from 1ts",
+        Assert.assertEquals("wrong step to route1tls from 1ts",
                      HttpRouteDirector.LAYER_PROTOCOL, step);
 
         // There are some odd cases left over, like having a secure tunnel
@@ -497,5 +472,4 @@ public class TestRouteDirector extends TestCase {
         // proxy that becomes unsecure by tunnelling to another proxy.
     }
 
-
-} // class TestRouteDirector
+}
