@@ -27,10 +27,6 @@ package org.apache.http.impl.client;
 
 import java.io.IOException;
 
-import junit.framework.Test;
-import junit.framework.TestSuite;
-
-import org.apache.http.HttpEntity;
 import org.apache.http.HttpException;
 import org.apache.http.HttpHost;
 import org.apache.http.HttpRequest;
@@ -40,44 +36,34 @@ import org.apache.http.client.HttpClient;
 import org.apache.http.client.UserTokenHandler;
 import org.apache.http.client.methods.HttpGet;
 import org.apache.http.conn.ManagedClientConnection;
-import org.apache.http.conn.params.ConnPerRouteBean;
-import org.apache.http.conn.params.ConnManagerParams;
 import org.apache.http.entity.StringEntity;
 import org.apache.http.impl.conn.tsccm.ThreadSafeClientConnManager;
 import org.apache.http.localserver.ServerTestBase;
+import org.apache.http.params.BasicHttpParams;
+import org.apache.http.params.HttpConnectionParams;
 import org.apache.http.params.HttpParams;
 import org.apache.http.protocol.BasicHttpContext;
 import org.apache.http.protocol.ExecutionContext;
 import org.apache.http.protocol.HttpContext;
 import org.apache.http.protocol.HttpRequestHandler;
+import org.apache.http.util.EntityUtils;
+import org.junit.Assert;
+import org.junit.Test;
 
 /**
  * Unit tests for {@link DefaultRequestDirector}
  */
 public class TestStatefulConnManagement extends ServerTestBase {
 
-    public TestStatefulConnManagement(final String testName) {
-        super(testName);
-    }
+    private static class SimpleService implements HttpRequestHandler {
 
-    public static void main(String args[]) {
-        String[] testCaseName = { TestStatefulConnManagement.class.getName() };
-        junit.textui.TestRunner.main(testCaseName);
-    }
-
-    public static Test suite() {
-        return new TestSuite(TestStatefulConnManagement.class);
-    }
-    
-    private class SimpleService implements HttpRequestHandler {
-        
         public SimpleService() {
             super();
         }
 
         public void handle(
-                final HttpRequest request, 
-                final HttpResponse response, 
+                final HttpRequest request,
+                final HttpResponse response,
                 final HttpContext context) throws HttpException, IOException {
             response.setStatusCode(HttpStatus.SC_OK);
             StringEntity entity = new StringEntity("Whatever");
@@ -85,27 +71,27 @@ public class TestStatefulConnManagement extends ServerTestBase {
         }
     }
 
+    @Test
     public void testStatefulConnections() throws Exception {
 
         int workerCount = 5;
         int requestCount = 5;
-        
-        int port = this.localServer.getServicePort();
+
+        int port = this.localServer.getServiceAddress().getPort();
         this.localServer.register("*", new SimpleService());
 
         HttpHost target = new HttpHost("localhost", port);
-        
-        HttpParams params = defaultParams.copy();
-        ConnManagerParams.setMaxTotalConnections(params, workerCount);
-        ConnManagerParams.setMaxConnectionsPerRoute(params, 
-                new ConnPerRouteBean(workerCount));
-        ConnManagerParams.setTimeout(params, 10L);
-        
-        ThreadSafeClientConnManager mgr = new ThreadSafeClientConnManager(
-                params, supportedSchemes);        
-        
-        DefaultHttpClient client = new DefaultHttpClient(mgr, params); 
-        
+
+        HttpParams params = new BasicHttpParams();
+        HttpConnectionParams.setConnectionTimeout(params, 10);
+
+        ThreadSafeClientConnManager mgr = new ThreadSafeClientConnManager(supportedSchemes);
+        mgr.setMaxTotal(workerCount);
+        mgr.setDefaultMaxPerRoute(workerCount);
+
+
+        DefaultHttpClient client = new DefaultHttpClient(mgr, params);
+
         HttpContext[] contexts = new HttpContext[workerCount];
         HttpWorker[] workers = new HttpWorker[workerCount];
         for (int i = 0; i < contexts.length; i++) {
@@ -114,17 +100,17 @@ public class TestStatefulConnManagement extends ServerTestBase {
             contexts[i] = context;
             workers[i] = new HttpWorker(context, requestCount, target, client);
         }
-        
+
         client.setUserTokenHandler(new UserTokenHandler() {
 
             public Object getUserToken(final HttpContext context) {
                 Integer id = (Integer) context.getAttribute("user");
                 return id;
             }
-            
+
         });
-        
-        
+
+
         for (int i = 0; i < workers.length; i++) {
             workers[i].start();
         }
@@ -136,34 +122,34 @@ public class TestStatefulConnManagement extends ServerTestBase {
             if (ex != null) {
                 throw ex;
             }
-            assertEquals(requestCount, workers[i].getCount());
+            Assert.assertEquals(requestCount, workers[i].getCount());
         }
-        
+
         for (int i = 0; i < contexts.length; i++) {
             HttpContext context = contexts[i];
             Integer id = (Integer) context.getAttribute("user");
-            
+
             for (int r = 0; r < requestCount; r++) {
                 Integer state = (Integer) context.getAttribute("r" + r);
-                assertNotNull(state);
-                assertEquals(id, state);
+                Assert.assertNotNull(state);
+                Assert.assertEquals(id, state);
             }
         }
-        
+
     }
-    
+
     static class HttpWorker extends Thread {
 
         private final HttpContext context;
         private final int requestCount;
         private final HttpHost target;
         private final HttpClient httpclient;
-        
+
         private volatile Exception exception;
         private volatile int count;
-        
+
         public HttpWorker(
-                final HttpContext context, 
+                final HttpContext context,
                 int requestCount,
                 final HttpHost target,
                 final HttpClient httpclient) {
@@ -174,7 +160,7 @@ public class TestStatefulConnManagement extends ServerTestBase {
             this.httpclient = httpclient;
             this.count = 0;
         }
-        
+
         public int getCount() {
             return this.count;
         }
@@ -189,29 +175,27 @@ public class TestStatefulConnManagement extends ServerTestBase {
                 for (int r = 0; r < this.requestCount; r++) {
                     HttpGet httpget = new HttpGet("/");
                     HttpResponse response = this.httpclient.execute(
-                            this.target, 
-                            httpget, 
+                            this.target,
+                            httpget,
                             this.context);
                     this.count++;
 
                     ManagedClientConnection conn = (ManagedClientConnection) this.context.getAttribute(
                             ExecutionContext.HTTP_CONNECTION);
-                    
+
                     this.context.setAttribute("r" + r, conn.getState());
-                    
-                    HttpEntity entity = response.getEntity();
-                    if (entity != null) {
-                        entity.consumeContent();
-                    }
+
+                    EntityUtils.consume(response.getEntity());
                 }
-                
+
             } catch (Exception ex) {
                 this.exception = ex;
             }
         }
-        
+
     }
 
+    @Test
     public void testRouteSpecificPoolRecylcing() throws Exception {
         // This tests what happens when a maxed connection pool needs
         // to kill the last idle connection to a route to build a new
@@ -219,19 +203,15 @@ public class TestStatefulConnManagement extends ServerTestBase {
 
         int maxConn = 2;
 
-        int port = this.localServer.getServicePort();
+        int port = this.localServer.getServiceAddress().getPort();
         this.localServer.register("*", new SimpleService());
 
         // We build a client with 2 max active // connections, and 2 max per route.
-        HttpParams params = defaultParams.copy();
-        ConnManagerParams.setMaxTotalConnections(params, maxConn);
-        ConnManagerParams.setMaxConnectionsPerRoute(params, 
-                new ConnPerRouteBean(maxConn));
-        
-        ThreadSafeClientConnManager connMngr = new ThreadSafeClientConnManager(
-                params, supportedSchemes);        
+        ThreadSafeClientConnManager connMngr = new ThreadSafeClientConnManager(supportedSchemes);
+        connMngr.setMaxTotal(maxConn);
+        connMngr.setDefaultMaxPerRoute(maxConn);
 
-        DefaultHttpClient client = new DefaultHttpClient(connMngr, params);
+        DefaultHttpClient client = new DefaultHttpClient(connMngr);
 
         client.setUserTokenHandler(new UserTokenHandler() {
 
@@ -246,10 +226,7 @@ public class TestStatefulConnManagement extends ServerTestBase {
         context1.setAttribute("user", "stuff");
         HttpResponse response1 = client.execute(
                 new HttpHost("localhost", port), new HttpGet("/"), context1);
-        HttpEntity entity1 = response1.getEntity();
-        if (entity1 != null) {
-            entity1.consumeContent();
-        }
+        EntityUtils.consume(response1.getEntity());
 
         // The ConnPoolByRoute now has 1 free connection, out of 2 max
         // The ConnPoolByRoute has one RouteSpcfcPool, that has one free connection
@@ -262,10 +239,7 @@ public class TestStatefulConnManagement extends ServerTestBase {
         HttpContext context2 = new BasicHttpContext();
         HttpResponse response2 = client.execute(
                 new HttpHost("127.0.0.1", port), new HttpGet("/"), context2);
-        HttpEntity entity2 = response2.getEntity();
-        if (entity2 != null) {
-            entity2.consumeContent();
-        }
+        EntityUtils.consume(response2.getEntity());
         // ConnPoolByRoute now has 2 free connexions, out of its 2 max.
         // The [localhost][stuff] RouteSpcfcPool is the same as earlier
         // And there is a [127.0.0.1][null] pool with 1 free connection
@@ -284,10 +258,7 @@ public class TestStatefulConnManagement extends ServerTestBase {
         // If the ConnPoolByRoute did not behave coherently with the RouteSpecificPool
         // this may fail. Ex : if the ConnPool discared the route pool because it was empty,
         // but still used it to build the request3 connection.
-        HttpEntity entity3 = response3.getEntity();
-        if (entity3 != null) {
-            entity3.consumeContent();
-        }
+        EntityUtils.consume(response3.getEntity());
 
     }
 
