@@ -29,83 +29,57 @@ package org.apache.http.impl.conn;
 
 import java.util.concurrent.TimeUnit;
 
-import junit.framework.Test;
-import junit.framework.TestCase;
-import junit.framework.TestSuite;
-
 import org.apache.http.HttpHost;
 import org.apache.http.HttpVersion;
 import org.apache.http.conn.ClientConnectionManager;
 import org.apache.http.conn.ClientConnectionRequest;
 import org.apache.http.conn.ConnectionPoolTimeoutException;
 import org.apache.http.conn.ManagedClientConnection;
-import org.apache.http.conn.params.ConnPerRouteBean;
-import org.apache.http.conn.params.ConnManagerParams;
 import org.apache.http.conn.routing.HttpRoute;
 import org.apache.http.conn.scheme.PlainSocketFactory;
 import org.apache.http.conn.scheme.Scheme;
 import org.apache.http.conn.scheme.SchemeRegistry;
-import org.apache.http.conn.scheme.SocketFactory;
 import org.apache.http.impl.conn.tsccm.ThreadSafeClientConnManager;
 import org.apache.http.params.BasicHttpParams;
 import org.apache.http.params.HttpParams;
 import org.apache.http.params.HttpProtocolParams;
-
+import org.junit.Assert;
+import org.junit.Test;
 
 /**
  * Tests for <code>ThreadSafeClientConnManager</code> that do not require
  * a server to communicate with.
  */
-public class TestTSCCMNoServer extends TestCase {
-
-    public TestTSCCMNoServer(String testName) {
-        super(testName);
-    }
-
-    public static void main(String args[]) {
-        String[] testCaseName = { TestTSCCMNoServer.class.getName() };
-        junit.textui.TestRunner.main(testCaseName);
-    }
-
-    public static Test suite() {
-        return new TestSuite(TestTSCCMNoServer.class);
-    }
-
+public class TestTSCCMNoServer {
 
     private static ManagedClientConnection getConnection(
-            final ClientConnectionManager mgr, 
+            final ClientConnectionManager mgr,
             final HttpRoute route,
             long timeout,
             TimeUnit unit) throws ConnectionPoolTimeoutException, InterruptedException {
         ClientConnectionRequest connRequest = mgr.requestConnection(route, null);
         return connRequest.getConnection(timeout, unit);
     }
-    
+
     private static ManagedClientConnection getConnection(
-            final ClientConnectionManager mgr, 
+            final ClientConnectionManager mgr,
             final HttpRoute route) throws ConnectionPoolTimeoutException, InterruptedException {
         ClientConnectionRequest connRequest = mgr.requestConnection(route, null);
         return connRequest.getConnection(0, null);
     }
-    
+
     /**
      * Helper to instantiate a <code>ThreadSafeClientConnManager</code>.
      *
-     * @param params    the parameters, or
-     *                  <code>null</code> to use defaults
      * @param schreg    the scheme registry, or
      *                  <code>null</code> to use defaults
      *
      * @return  a connection manager to test
      */
-    public ThreadSafeClientConnManager createTSCCM(HttpParams params,
-                                                   SchemeRegistry schreg) {
-        if (params == null)
-            params = createDefaultParams();
+    public ThreadSafeClientConnManager createTSCCM(SchemeRegistry schreg) {
         if (schreg == null)
             schreg = createSchemeRegistry();
-
-        return new ThreadSafeClientConnManager(params, schreg);
+        return new ThreadSafeClientConnManager(schreg);
     }
 
 
@@ -131,78 +105,56 @@ public class TestTSCCMNoServer extends TestCase {
     public SchemeRegistry createSchemeRegistry() {
 
         SchemeRegistry schreg = new SchemeRegistry();
-        SocketFactory sf = PlainSocketFactory.getSocketFactory();
-        schreg.register(new Scheme("http", sf, 80));
+        schreg.register(new Scheme("http", 80, PlainSocketFactory.getSocketFactory()));
 
         return schreg;
     }
 
-
+    @Test
     public void testConstructor() {
-        HttpParams     params = createDefaultParams();
         SchemeRegistry schreg = createSchemeRegistry();
 
-        ThreadSafeClientConnManager mgr =
-            new ThreadSafeClientConnManager(params, schreg);
-        assertNotNull(mgr);
+        ThreadSafeClientConnManager mgr = new ThreadSafeClientConnManager(schreg);
+        Assert.assertNotNull(mgr);
         mgr.shutdown();
-        mgr = null;
+    }
 
-        try {
-            mgr = new ThreadSafeClientConnManager(null, schreg);
-            fail("null parameters not detected");
-        } catch (IllegalArgumentException iax) {
-            // expected
-        } finally {
-            if (mgr != null)
-                mgr.shutdown();
-        }
-        mgr = null;
+    @Test(expected=IllegalArgumentException.class)
+    public void testIllegalConstructor() {
+        new ThreadSafeClientConnManager(null);
+    }
 
-        mgr = new ThreadSafeClientConnManager(params, schreg);
-        assertNotNull(mgr);
-        mgr.shutdown();
-        mgr = null;
-
-    } // testConstructor
-
-
-    public void testGetConnection() 
+    @Test(expected=IllegalArgumentException.class)
+    public void testGetConnection()
             throws InterruptedException, ConnectionPoolTimeoutException {
-        ThreadSafeClientConnManager mgr = createTSCCM(null, null);
+        ThreadSafeClientConnManager mgr = createTSCCM(null);
 
         HttpHost target = new HttpHost("www.test.invalid", 80, "http");
         HttpRoute route = new HttpRoute(target, null, false);
 
         ManagedClientConnection conn = getConnection(mgr, route);
-        assertNotNull(conn);
-        assertNull(conn.getRoute());
-        assertFalse(conn.isOpen());
+        Assert.assertNotNull(conn);
+        Assert.assertNull(conn.getRoute());
+        Assert.assertFalse(conn.isOpen());
 
         mgr.releaseConnection(conn, -1, null);
 
         try {
-            conn = getConnection(mgr, null);
-            fail("null route not detected");
-        } catch (IllegalArgumentException iax) {
-            // expected
+            getConnection(mgr, null);
+        } finally {
+            mgr.shutdown();
         }
-
-        mgr.shutdown();
     }
 
     // testTimeout in 3.x TestHttpConnectionManager is redundant
     // several other tests here rely on timeout behavior
-
-
-    public void testMaxConnTotal() 
+    @Test
+    public void testMaxConnTotal()
             throws InterruptedException, ConnectionPoolTimeoutException {
 
-        HttpParams params = createDefaultParams();
-        ConnManagerParams.setMaxConnectionsPerRoute(params, new ConnPerRouteBean(1));
-        ConnManagerParams.setMaxTotalConnections(params, 2);
-
-        ThreadSafeClientConnManager mgr = createTSCCM(params, null);
+        ThreadSafeClientConnManager mgr = createTSCCM(null);
+        mgr.setMaxTotal(2);
+        mgr.setDefaultMaxPerRoute(1);
 
         HttpHost target1 = new HttpHost("www.test1.invalid", 80, "http");
         HttpRoute route1 = new HttpRoute(target1, null, false);
@@ -210,34 +162,33 @@ public class TestTSCCMNoServer extends TestCase {
         HttpRoute route2 = new HttpRoute(target2, null, false);
 
         ManagedClientConnection conn1 = getConnection(mgr, route1);
-        assertNotNull(conn1);
+        Assert.assertNotNull(conn1);
         ManagedClientConnection conn2 = getConnection(mgr, route2);
-        assertNotNull(conn2);
+        Assert.assertNotNull(conn2);
 
         try {
             // this should fail quickly, connection has not been released
             getConnection(mgr, route2, 100L, TimeUnit.MILLISECONDS);
-            fail("ConnectionPoolTimeoutException should have been thrown");
+            Assert.fail("ConnectionPoolTimeoutException should have been thrown");
         } catch (ConnectionPoolTimeoutException e) {
             // expected
         }
-        
+
         // release one of the connections
         mgr.releaseConnection(conn2, -1, null);
         conn2 = null;
 
         // there should be a connection available now
         try {
-            conn2 = getConnection(mgr, route2, 100L, TimeUnit.MILLISECONDS);
+            getConnection(mgr, route2, 100L, TimeUnit.MILLISECONDS);
         } catch (ConnectionPoolTimeoutException cptx) {
-            cptx.printStackTrace();
-            fail("connection should have been available: " + cptx);
+            Assert.fail("connection should have been available: " + cptx);
         }
 
         mgr.shutdown();
     }
 
-
+    @Test
     public void testMaxConnPerHost() throws Exception {
 
         HttpHost target1 = new HttpHost("www.test1.invalid", 80, "http");
@@ -246,43 +197,38 @@ public class TestTSCCMNoServer extends TestCase {
         HttpRoute route2 = new HttpRoute(target2, null, false);
         HttpHost target3 = new HttpHost("www.test3.invalid", 80, "http");
         HttpRoute route3 = new HttpRoute(target3, null, false);
-        
-        HttpParams params = createDefaultParams();
-        ConnManagerParams.setMaxTotalConnections(params, 100);
-        
-        ConnPerRouteBean connPerRoute = new ConnPerRouteBean(1);
-        connPerRoute.setMaxForRoute(route2, 2);
-        connPerRoute.setMaxForRoute(route3, 3);
-        
-        ConnManagerParams.setMaxConnectionsPerRoute(params, connPerRoute);
 
-        ThreadSafeClientConnManager mgr = createTSCCM(params, null);
+        ThreadSafeClientConnManager mgr = createTSCCM(null);
+        mgr.setMaxTotal(100);
+        mgr.setDefaultMaxPerRoute(1);
+        mgr.setMaxForRoute(route2, 2);
+        mgr.setMaxForRoute(route3, 3);
 
         // route 3, limit 3
         ManagedClientConnection conn1 =
             getConnection(mgr, route3, 10L, TimeUnit.MILLISECONDS);
-        assertNotNull(conn1);
+        Assert.assertNotNull(conn1);
         ManagedClientConnection conn2 =
             getConnection(mgr, route3, 10L, TimeUnit.MILLISECONDS);
-        assertNotNull(conn2);
+        Assert.assertNotNull(conn2);
         ManagedClientConnection conn3 =
             getConnection(mgr, route3, 10L, TimeUnit.MILLISECONDS);
-        assertNotNull(conn3);
+        Assert.assertNotNull(conn3);
         try {
             // should fail quickly, connection has not been released
             getConnection(mgr, route3, 10L, TimeUnit.MILLISECONDS);
-            fail("ConnectionPoolTimeoutException should have been thrown");
+            Assert.fail("ConnectionPoolTimeoutException should have been thrown");
         } catch (ConnectionPoolTimeoutException e) {
             // expected
         }
-        
+
         // route 2, limit 2
         conn1 = getConnection(mgr, route2, 10L, TimeUnit.MILLISECONDS);
         conn2 = getConnection(mgr, route2, 10L, TimeUnit.MILLISECONDS);
         try {
             // should fail quickly, connection has not been released
             getConnection(mgr, route2, 10L, TimeUnit.MILLISECONDS);
-            fail("ConnectionPoolTimeoutException should have been thrown");
+            Assert.fail("ConnectionPoolTimeoutException should have been thrown");
         } catch (ConnectionPoolTimeoutException e) {
             // expected
         }
@@ -292,7 +238,7 @@ public class TestTSCCMNoServer extends TestCase {
         try {
             // should fail quickly, connection has not been released
             getConnection(mgr, route1, 10L, TimeUnit.MILLISECONDS);
-            fail("ConnectionPoolTimeoutException should have been thrown");
+            Assert.fail("ConnectionPoolTimeoutException should have been thrown");
         } catch (ConnectionPoolTimeoutException e) {
             // expected
         }
@@ -301,28 +247,26 @@ public class TestTSCCMNoServer extends TestCase {
         // check releaseConnection with invalid arguments
         try {
             mgr.releaseConnection(null, -1, null);
-            fail("null connection adapter not detected");
+            Assert.fail("null connection adapter not detected");
         } catch (IllegalArgumentException iax) {
             // expected
         }
         try {
             mgr.releaseConnection(new ClientConnAdapterMockup(null), -1, null);
-            fail("foreign connection adapter not detected");
+            Assert.fail("foreign connection adapter not detected");
         } catch (IllegalArgumentException iax) {
             // expected
         }
 
         mgr.shutdown();
-    }    
-
+    }
 
+    @Test
     public void testReleaseConnection() throws Exception {
 
-        HttpParams params = createDefaultParams();
-        ConnManagerParams.setMaxConnectionsPerRoute(params, new ConnPerRouteBean(1));
-        ConnManagerParams.setMaxTotalConnections(params, 3);
-
-        ThreadSafeClientConnManager mgr = createTSCCM(params, null);
+        ThreadSafeClientConnManager mgr = createTSCCM(null);
+        mgr.setMaxTotal(3);
+        mgr.setDefaultMaxPerRoute(1);
 
         HttpHost target1 = new HttpHost("www.test1.invalid", 80, "http");
         HttpRoute route1 = new HttpRoute(target1, null, false);
@@ -338,27 +282,27 @@ public class TestTSCCMNoServer extends TestCase {
             getConnection(mgr, route2, 10L, TimeUnit.MILLISECONDS);
         ManagedClientConnection conn3 =
             getConnection(mgr, route3, 10L, TimeUnit.MILLISECONDS);
-        assertNotNull(conn1);
-        assertNotNull(conn2);
-        assertNotNull(conn3);
+        Assert.assertNotNull(conn1);
+        Assert.assertNotNull(conn2);
+        Assert.assertNotNull(conn3);
 
         // obtaining another connection for either of the three should fail
         // this is somehow redundant with testMaxConnPerHost
         try {
             getConnection(mgr, route1, 10L, TimeUnit.MILLISECONDS);
-            fail("ConnectionPoolTimeoutException should have been thrown");
+            Assert.fail("ConnectionPoolTimeoutException should have been thrown");
         } catch (ConnectionPoolTimeoutException e) {
             // expected
         }
         try {
             getConnection(mgr, route2, 10L, TimeUnit.MILLISECONDS);
-            fail("ConnectionPoolTimeoutException should have been thrown");
+            Assert.fail("ConnectionPoolTimeoutException should have been thrown");
         } catch (ConnectionPoolTimeoutException e) {
             // expected
         }
         try {
             getConnection(mgr, route3, 10L, TimeUnit.MILLISECONDS);
-            fail("ConnectionPoolTimeoutException should have been thrown");
+            Assert.fail("ConnectionPoolTimeoutException should have been thrown");
         } catch (ConnectionPoolTimeoutException e) {
             // expected
         }
@@ -368,16 +312,16 @@ public class TestTSCCMNoServer extends TestCase {
         conn2 = null;
         try {
             getConnection(mgr, route1, 10L, TimeUnit.MILLISECONDS);
-            fail("ConnectionPoolTimeoutException should have been thrown");
+            Assert.fail("ConnectionPoolTimeoutException should have been thrown");
         } catch (ConnectionPoolTimeoutException e) {
             // expected
         }
         // this one succeeds
         conn2 = getConnection(mgr, route2, 10L, TimeUnit.MILLISECONDS);
-        assertNotNull(conn2);
+        Assert.assertNotNull(conn2);
         try {
             getConnection(mgr, route3, 10L, TimeUnit.MILLISECONDS);
-            fail("ConnectionPoolTimeoutException should have been thrown");
+            Assert.fail("ConnectionPoolTimeoutException should have been thrown");
         } catch (ConnectionPoolTimeoutException e) {
             // expected
         }
@@ -385,47 +329,46 @@ public class TestTSCCMNoServer extends TestCase {
         mgr.shutdown();
     }
 
-
+    @Test
     public void testDeleteClosedConnections()
             throws InterruptedException, ConnectionPoolTimeoutException {
-        
-        ThreadSafeClientConnManager mgr = createTSCCM(null, null);
+
+        ThreadSafeClientConnManager mgr = createTSCCM(null);
 
         HttpHost target = new HttpHost("www.test.invalid", 80, "http");
         HttpRoute route = new HttpRoute(target, null, false);
 
         ManagedClientConnection conn = getConnection(mgr, route);
 
-        assertEquals("connectionsInPool",
+        Assert.assertEquals("connectionsInPool",
                      mgr.getConnectionsInPool(), 1);
-        assertEquals("connectionsInPool(host)",
+        Assert.assertEquals("connectionsInPool(host)",
                      mgr.getConnectionsInPool(route), 1);
         mgr.releaseConnection(conn, -1, null);
 
-        assertEquals("connectionsInPool",
+        Assert.assertEquals("connectionsInPool",
                      mgr.getConnectionsInPool(), 1);
-        assertEquals("connectionsInPool(host)",
+        Assert.assertEquals("connectionsInPool(host)",
                      mgr.getConnectionsInPool(route), 1);
 
         // this implicitly deletes them
         mgr.closeIdleConnections(0L, TimeUnit.MILLISECONDS);
 
-        assertEquals("connectionsInPool",
+        Assert.assertEquals("connectionsInPool",
                      mgr.getConnectionsInPool(), 0);
-        assertEquals("connectionsInPool(host)",
+        Assert.assertEquals("connectionsInPool(host)",
                      mgr.getConnectionsInPool(route), 0);
 
         mgr.shutdown();
     }
 
+    @Test
     public void testShutdown() throws Exception {
         // 3.x: TestHttpConnectionManager.testShutdown
 
-        HttpParams params = createDefaultParams();
-        ConnManagerParams.setMaxConnectionsPerRoute(params, new ConnPerRouteBean(1));
-        ConnManagerParams.setMaxTotalConnections(params, 1);
-
-        ThreadSafeClientConnManager mgr = createTSCCM(params, null);
+        ThreadSafeClientConnManager mgr = createTSCCM(null);
+        mgr.setMaxTotal(1);
+        mgr.setDefaultMaxPerRoute(1);
 
         HttpHost target = new HttpHost("www.test.invalid", 80, "http");
         HttpRoute route = new HttpRoute(target, null, false);
@@ -449,30 +392,28 @@ public class TestTSCCMNoServer extends TestCase {
 
 
         gct.join(10000);
-        assertNull("thread should not have obtained connection",
+        Assert.assertNull("thread should not have obtained connection",
                    gct.getConnection());
-        assertNotNull("thread should have gotten an exception",
+        Assert.assertNotNull("thread should have gotten an exception",
                       gct.getException());
-        assertSame("thread got wrong exception",
+        Assert.assertSame("thread got wrong exception",
                    IllegalStateException.class, gct.getException().getClass());
 
         // the manager is down, we should not be able to get a connection
         try {
-            conn = getConnection(mgr, route, 1L, TimeUnit.MILLISECONDS);
-            fail("shut-down manager does not raise exception");
+            getConnection(mgr, route, 1L, TimeUnit.MILLISECONDS);
+            Assert.fail("shut-down manager does not raise exception");
         } catch (IllegalStateException isx) {
             // expected
         }
     }
 
-
+    @Test
     public void testInterruptThread() throws Exception {
         // 3.x: TestHttpConnectionManager.testWaitingThreadInterrupted
 
-        HttpParams params = createDefaultParams();
-        ConnManagerParams.setMaxTotalConnections(params, 1);
-
-        ThreadSafeClientConnManager mgr = createTSCCM(params, null);
+        ThreadSafeClientConnManager mgr = createTSCCM(null);
+        mgr.setMaxTotal(1);
 
         HttpHost target = new HttpHost("www.test.invalid", 80, "http");
         HttpRoute route = new HttpRoute(target, null, false);
@@ -490,16 +431,16 @@ public class TestTSCCMNoServer extends TestCase {
 
 
         gct.join(10000);
-        assertNotNull("thread should have gotten an exception",
+        Assert.assertNotNull("thread should have gotten an exception",
                       gct.getException());
-        assertSame("thread got wrong exception",
+        Assert.assertSame("thread got wrong exception",
                    InterruptedException.class,
                    gct.getException().getClass());
 
         // make sure the manager is still working
         try {
             getConnection(mgr, route, 10L, TimeUnit.MILLISECONDS);
-            fail("should have gotten a timeout");
+            Assert.fail("should have gotten a timeout");
         } catch (ConnectionPoolTimeoutException e) {
             // expected
         }
@@ -507,20 +448,17 @@ public class TestTSCCMNoServer extends TestCase {
         mgr.releaseConnection(conn, -1, null);
         // this time: no exception
         conn = getConnection(mgr, route, 10L, TimeUnit.MILLISECONDS);
-        assertNotNull("should have gotten a connection", conn);
+        Assert.assertNotNull("should have gotten a connection", conn);
 
         mgr.shutdown();
     }
 
-
-
+    @Test
     public void testReusePreference() throws Exception {
         // 3.x: TestHttpConnectionManager.testHostReusePreference
 
-        HttpParams params = createDefaultParams();
-        ConnManagerParams.setMaxTotalConnections(params, 1);
-
-        ThreadSafeClientConnManager mgr = createTSCCM(params, null);
+        ThreadSafeClientConnManager mgr = createTSCCM(null);
+        mgr.setMaxTotal(1);
 
         HttpHost target1 = new HttpHost("www.test1.invalid", 80, "http");
         HttpRoute route1 = new HttpRoute(target1, null, false);
@@ -548,23 +486,22 @@ public class TestTSCCMNoServer extends TestCase {
         gct1.join(10000);
         gct2.join(10000);
 
-        assertNotNull("thread 1 should have gotten a connection",
+        Assert.assertNotNull("thread 1 should have gotten a connection",
                       gct1.getConnection());
-        assertNull   ("thread 2 should NOT have gotten a connection",
+        Assert.assertNull   ("thread 2 should NOT have gotten a connection",
                       gct2.getConnection());
 
         mgr.shutdown();
     }
-    
+
+    @Test
     public void testAbortAfterRequestStarts() throws Exception {
-        HttpParams params = createDefaultParams();
-        ConnManagerParams.setMaxTotalConnections(params, 1);
-
-        ThreadSafeClientConnManager mgr = createTSCCM(params, null);
+        ThreadSafeClientConnManager mgr = createTSCCM(null);
+        mgr.setMaxTotal(1);
 
         HttpHost target = new HttpHost("www.test.invalid", 80, "http");
         HttpRoute route = new HttpRoute(target, null, false);
-        
+
         // get the only connection, then start an extra thread
         ManagedClientConnection conn = getConnection(mgr, route, 1L, TimeUnit.MILLISECONDS);
         ClientConnectionRequest request = mgr.requestConnection(route, null);
@@ -575,16 +512,16 @@ public class TestTSCCMNoServer extends TestCase {
         request.abortRequest();
 
         gct.join(10000);
-        assertNotNull("thread should have gotten an exception",
+        Assert.assertNotNull("thread should have gotten an exception",
                       gct.getException());
-        assertSame("thread got wrong exception",
+        Assert.assertSame("thread got wrong exception",
                    InterruptedException.class,
                    gct.getException().getClass());
 
         // make sure the manager is still working
         try {
             getConnection(mgr, route, 10L, TimeUnit.MILLISECONDS);
-            fail("should have gotten a timeout");
+            Assert.fail("should have gotten a timeout");
         } catch (ConnectionPoolTimeoutException e) {
             // expected
         }
@@ -592,41 +529,39 @@ public class TestTSCCMNoServer extends TestCase {
         mgr.releaseConnection(conn, -1, null);
         // this time: no exception
         conn = getConnection(mgr, route, 10L, TimeUnit.MILLISECONDS);
-        assertNotNull("should have gotten a connection", conn);
+        Assert.assertNotNull("should have gotten a connection", conn);
 
         mgr.shutdown();
     }
-    
+
+    @Test
     public void testAbortBeforeRequestStarts() throws Exception {
-        HttpParams params = createDefaultParams();
-        ConnManagerParams.setMaxTotalConnections(params, 1);
-
-        ThreadSafeClientConnManager mgr = createTSCCM(params, null);
+        ThreadSafeClientConnManager mgr = createTSCCM(null);
+        mgr.setMaxTotal(1);
 
         HttpHost target = new HttpHost("www.test.invalid", 80, "http");
         HttpRoute route = new HttpRoute(target, null, false);
-        
 
         // get the only connection, then start an extra thread
         ManagedClientConnection conn = getConnection(mgr, route, 1L, TimeUnit.MILLISECONDS);
         ClientConnectionRequest request = mgr.requestConnection(route, null);
         request.abortRequest();
-        
+
         GetConnThread gct = new GetConnThread(request, route, 0L); // no timeout
         gct.start();
         Thread.sleep(100); // give extra thread time to block
 
         gct.join(10000);
-        assertNotNull("thread should have gotten an exception",
+        Assert.assertNotNull("thread should have gotten an exception",
                       gct.getException());
-        assertSame("thread got wrong exception",
+        Assert.assertSame("thread got wrong exception",
                    InterruptedException.class,
                    gct.getException().getClass());
 
         // make sure the manager is still working
         try {
             getConnection(mgr, route, 10L, TimeUnit.MILLISECONDS);
-            fail("should have gotten a timeout");
+            Assert.fail("should have gotten a timeout");
         } catch (ConnectionPoolTimeoutException e) {
             // expected
         }
@@ -634,9 +569,9 @@ public class TestTSCCMNoServer extends TestCase {
         mgr.releaseConnection(conn, -1, null);
         // this time: no exception
         conn = getConnection(mgr, route, 10L, TimeUnit.MILLISECONDS);
-        assertNotNull("should have gotten a connection", conn);
+        Assert.assertNotNull("should have gotten a connection", conn);
 
         mgr.shutdown();
     }
 
-} // class TestTSCCMNoServer
+}
